@@ -78,7 +78,7 @@ main (gint argc, gchar *argv[])
 	if(!g_option_context_parse (context, &p_argc, &p_argv, &error))
 	{
 	  fprintf (stderr, "Invalid run options:\n  %s.\n", error->message);
-	  printf (g_option_context_get_help (context, TRUE, NULL));
+	  printf ("%s", g_option_context_get_help (context, TRUE, NULL));
 	  g_option_context_free (context);
 	  return 0;
 	}
@@ -98,7 +98,7 @@ main (gint argc, gchar *argv[])
 	if (!g_key_file_load_from_file (runconf, de_run.runconf, G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS, &error))
 	{
 	  fprintf (stderr, "Invalid run configuration file: %s\n  %s\n", de_run.runconf, error->message);
-	  printf (g_option_context_get_help (context, TRUE, NULL));
+	  printf ("%s", g_option_context_get_help (context, TRUE, NULL));
 	  return 0;
 	}
 
@@ -112,7 +112,7 @@ main (gint argc, gchar *argv[])
 	if(!g_option_context_parse (context, &runconf_argc, &runconf_argv, &error))
 	{
 	  fprintf (stderr, "Invalid configuration file options:\n  %s.\n", error->message);
-	  printf (g_option_context_get_help (context, TRUE, NULL));
+	  printf ("%s", g_option_context_get_help (context, TRUE, NULL));
 	  g_option_context_free (context);
 	  return 0;
 	}
@@ -120,7 +120,7 @@ main (gint argc, gchar *argv[])
 	if(!g_option_context_parse (context, &argc, &argv, &error))
 	{
 	  fprintf (stderr, "Invalid run options:\n  %s.\n", error->message);
-	  printf (g_option_context_get_help (context, TRUE, NULL));
+	  printf ("%s", g_option_context_get_help (context, TRUE, NULL));
 	  g_option_context_free (context);
 	  return 0;
 	}
@@ -158,7 +158,7 @@ main (gint argc, gchar *argv[])
       de_data_simple.cluster_id == NULL)
   {
 	printf ("No action or data was chosen.\n");
-	printf (g_option_context_get_help (context, TRUE, NULL));
+	printf ("%s", g_option_context_get_help (context, TRUE, NULL));
 	g_option_context_free (context);
 	return 0;
   }
@@ -196,6 +196,11 @@ main (gint argc, gchar *argv[])
 	ncm_mset_param_set_ftype (mset, NC_HICOSMO_ID, NC_HICOSMO_DE_OMEGA_X, NCM_PARAM_TYPE_FREE);
   }
 
+  if (de_model.pos_Omega_x)
+  {
+	nc_prior_add_positive (lh, NC_HICOSMO_ID, NC_HICOSMO_DE_OMEGA_X);
+  }
+
   if (de_data_simple.snia_id != NULL)
   {
 	const GEnumValue *snia_id = ncm_cfg_get_enum_by_id_name_nick (NC_TYPE_DATA_DISTANCE_MU_SN_IA_ID,
@@ -277,7 +282,7 @@ main (gint argc, gchar *argv[])
   de_fit.fisher = (de_fit.fisher || (de_fit.nsigma_fisher != -1) || (de_fit.nsigma != -1) || (de_fit.onedim_cr != NULL));
   de_fit.fit = (de_fit.fit || de_fit.fisher);
   de_fit.save_best_fit = (de_fit.save_best_fit || de_fit.save_fisher || (de_fit.nsigma_fisher != -1) || (de_fit.nsigma != -1));
-
+  
   if (de_fit.fit)
   {
 	fit->params_prec_target = 1e-5;
@@ -329,6 +334,9 @@ main (gint argc, gchar *argv[])
 	else
 	  resample_mset = fit->mset;
 
+	nc_dataset_log_info (fit->lh->ds);
+	ncm_mset_pretty_log (resample_mset);
+		
 	param_matrix = ncm_fit_montecarlo_matrix (fit, resample_mset, de_fit.max_iter, de_fit.mc_ni, de_fit.montecarlo, de_fit.msg_level);
 	ncm_fit_montecarlo_matrix_mean_covar (fit, param_matrix);
 	ncm_fit_log_covar (fit);
@@ -337,7 +345,7 @@ main (gint argc, gchar *argv[])
 
 	ncm_matrix_free (param_matrix);
   }
-
+  
   if (de_fit.onedim_cr != NULL)
   {
 	while (de_fit.onedim_cr[0] != NULL)
@@ -348,16 +356,16 @@ main (gint argc, gchar *argv[])
 	  switch (de_fit.nsigma)
 	  {
 		case 1:
-		  prob_sigma = NC_C_STATS_1SIGMA;
+		  prob_sigma = ncm_c_stats_1sigma ();
 		  break;
 		case 2:
-		  prob_sigma = NC_C_STATS_2SIGMA;
+		  prob_sigma = ncm_c_stats_2sigma ();
 		  break;
 		case 3:
-		  prob_sigma = NC_C_STATS_3SIGMA;
+		  prob_sigma = ncm_c_stats_3sigma ();
 		  break;
 		default:
-		  prob_sigma = NC_C_STATS_1SIGMA;
+		  prob_sigma = ncm_c_stats_1sigma ();
 		  break;
 	  }
 	  ncm_fit_cr_1dim (fit, NC_HICOSMO_ID, p_n, prob_sigma, 1, &err_inf, &err_sup);
@@ -388,18 +396,18 @@ main (gint argc, gchar *argv[])
 	switch (de_fit.nsigma)
 	{
 	  case 1:
-		points_1sigma = ncm_fit_cr2 (fit, NC_HICOSMO_ID, de_fit.bidim_cr[0], NC_HICOSMO_ID, de_fit.bidim_cr[1], NC_C_STATS_1SIGMA);
+		points_1sigma = ncm_fit_cr2 (fit, NC_HICOSMO_ID, de_fit.bidim_cr[0], NC_HICOSMO_ID, de_fit.bidim_cr[1], ncm_c_stats_1sigma ());
 		break;
 	  case 2:
-		points_2sigma = ncm_fit_cr2 (fit, NC_HICOSMO_ID, de_fit.bidim_cr[0], NC_HICOSMO_ID, de_fit.bidim_cr[1], NC_C_STATS_2SIGMA);
+		points_2sigma = ncm_fit_cr2 (fit, NC_HICOSMO_ID, de_fit.bidim_cr[0], NC_HICOSMO_ID, de_fit.bidim_cr[1], ncm_c_stats_2sigma ());
 		break;
 	  case 3:
-		points_3sigma = ncm_fit_cr2 (fit, NC_HICOSMO_ID, de_fit.bidim_cr[0], NC_HICOSMO_ID, de_fit.bidim_cr[1], NC_C_STATS_3SIGMA);
+		points_3sigma = ncm_fit_cr2 (fit, NC_HICOSMO_ID, de_fit.bidim_cr[0], NC_HICOSMO_ID, de_fit.bidim_cr[1], ncm_c_stats_3sigma ());
 		break;
 	  default:
-		points_1sigma = ncm_fit_cr2 (fit, NC_HICOSMO_ID, de_fit.bidim_cr[0], NC_HICOSMO_ID, de_fit.bidim_cr[1], NC_C_STATS_1SIGMA);
-		points_2sigma = ncm_fit_cr2 (fit, NC_HICOSMO_ID, de_fit.bidim_cr[0], NC_HICOSMO_ID, de_fit.bidim_cr[1], NC_C_STATS_2SIGMA);
-		points_3sigma = ncm_fit_cr2 (fit, NC_HICOSMO_ID, de_fit.bidim_cr[0], NC_HICOSMO_ID, de_fit.bidim_cr[1], NC_C_STATS_3SIGMA);
+		points_1sigma = ncm_fit_cr2 (fit, NC_HICOSMO_ID, de_fit.bidim_cr[0], NC_HICOSMO_ID, de_fit.bidim_cr[1], ncm_c_stats_1sigma ());
+		points_2sigma = ncm_fit_cr2 (fit, NC_HICOSMO_ID, de_fit.bidim_cr[0], NC_HICOSMO_ID, de_fit.bidim_cr[1], ncm_c_stats_2sigma ());
+		points_3sigma = ncm_fit_cr2 (fit, NC_HICOSMO_ID, de_fit.bidim_cr[0], NC_HICOSMO_ID, de_fit.bidim_cr[1], ncm_c_stats_3sigma ());
 		break;
 	}
 
@@ -448,18 +456,18 @@ main (gint argc, gchar *argv[])
 	switch (de_fit.nsigma_fisher)
 	{
 	  case 1:
-		points_1sigma = ncm_fit_cr2_fisher (fit, NC_HICOSMO_ID, de_fit.bidim_cr[0], NC_HICOSMO_ID, de_fit.bidim_cr[1], NC_C_STATS_1SIGMA);
+		points_1sigma = ncm_fit_cr2_fisher (fit, NC_HICOSMO_ID, de_fit.bidim_cr[0], NC_HICOSMO_ID, de_fit.bidim_cr[1], ncm_c_stats_1sigma ());
 		break;
 	  case 2:
-		points_2sigma = ncm_fit_cr2_fisher (fit, NC_HICOSMO_ID, de_fit.bidim_cr[0], NC_HICOSMO_ID, de_fit.bidim_cr[1], NC_C_STATS_2SIGMA);
+		points_2sigma = ncm_fit_cr2_fisher (fit, NC_HICOSMO_ID, de_fit.bidim_cr[0], NC_HICOSMO_ID, de_fit.bidim_cr[1], ncm_c_stats_2sigma ());
 		break;
 	  case 3:
-		points_3sigma = ncm_fit_cr2_fisher (fit, NC_HICOSMO_ID, de_fit.bidim_cr[0], NC_HICOSMO_ID, de_fit.bidim_cr[1], NC_C_STATS_3SIGMA);
+		points_3sigma = ncm_fit_cr2_fisher (fit, NC_HICOSMO_ID, de_fit.bidim_cr[0], NC_HICOSMO_ID, de_fit.bidim_cr[1], ncm_c_stats_3sigma ());
 		break;
 	  default:
-		points_1sigma = ncm_fit_cr2_fisher (fit, NC_HICOSMO_ID, de_fit.bidim_cr[0], NC_HICOSMO_ID, de_fit.bidim_cr[1], NC_C_STATS_1SIGMA);
-		points_2sigma = ncm_fit_cr2_fisher (fit, NC_HICOSMO_ID, de_fit.bidim_cr[0], NC_HICOSMO_ID, de_fit.bidim_cr[1], NC_C_STATS_2SIGMA);
-		points_3sigma = ncm_fit_cr2_fisher (fit, NC_HICOSMO_ID, de_fit.bidim_cr[0], NC_HICOSMO_ID, de_fit.bidim_cr[1], NC_C_STATS_3SIGMA);
+		points_1sigma = ncm_fit_cr2_fisher (fit, NC_HICOSMO_ID, de_fit.bidim_cr[0], NC_HICOSMO_ID, de_fit.bidim_cr[1], ncm_c_stats_1sigma ());
+		points_2sigma = ncm_fit_cr2_fisher (fit, NC_HICOSMO_ID, de_fit.bidim_cr[0], NC_HICOSMO_ID, de_fit.bidim_cr[1], ncm_c_stats_2sigma ());
+		points_3sigma = ncm_fit_cr2_fisher (fit, NC_HICOSMO_ID, de_fit.bidim_cr[0], NC_HICOSMO_ID, de_fit.bidim_cr[1], ncm_c_stats_3sigma ());
 		break;
 	}
 
