@@ -33,13 +33,14 @@
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
-#include <numcosmo/numcosmo.h>
+#include "build_cfg.h"
 
-#include <glib.h>
-#include <gsl/gsl_eigen.h>
-#include <gsl/gsl_blas.h>
+#include "data/data_gaussian.h"
+#include "math/util.h"
+
+#include <gsl/gsl_randist.h>
 #include <gsl/gsl_statistics_double.h>
-#include <gmp.h>
+#include <gsl/gsl_blas.h>
 #ifdef NUMCOSMO_HAVE_SQLITE3
 #include <sqlite3.h>
 #endif
