@@ -33,15 +33,16 @@
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
-#include <numcosmo/numcosmo.h>
+#include "build_cfg.h"
+
+#include "likelihood/confidence_region.h"
+#include "likelihood/priors.h"
+#include "math/util.h"
 
-#include <glib.h>
-#include <gsl/gsl_roots.h>
-#include <gsl/gsl_cdf.h>
-#include <gsl/gsl_rng.h>
 #include <gsl/gsl_eigen.h>
+#include <gsl/gsl_cdf.h>
+#include <gsl/gsl_roots.h>
 #include <gsl/gsl_blas.h>
-#include <gsl/gsl_deriv.h>
 
 static gboolean ncm_fit_cr_step (NcConfidenceRegion *cr, gdouble x);
 static gdouble nc_confidence_region_f (gdouble x, gpointer p);
@@ -396,10 +397,12 @@ ncm_fit_cr_points_free (GList *points)
 }
 
 /**
- * ncm_fit_cr2_fisher:
+ * ncm_fit_cr:
  * @fit: a #NcmFit
- * @n1: FIXME
- * @n2: FIXME
+ * @gmid1: FIXME
+ * @pid1: FIXME
+ * @gmid2: FIXME
+ * @pid2: FIXME
  * @p: FIXME
  *
  * FIXME
@@ -954,7 +957,7 @@ ncm_fit_cr_root_steffenson (NcConfidenceRegion *cr, gdouble x)
 	if (status)
 	{
 	  ncm_mset_params_print_vals (cr->constrained->mset, stdout);
-	  g_warning (gsl_strerror (status));
+	  g_warning ("%s", gsl_strerror (status));
 	  gsl_root_fdfsolver_free (s);
 	  return GSL_NAN;
 	}
@@ -1012,7 +1015,7 @@ ncm_fit_cr_root_brent (NcConfidenceRegion *cr, gdouble x0, gdouble x)
 	if (status)
 	{
 	  //      nc_params_print_all (cr->fit->mset, stdout);
-	  g_warning (gsl_strerror (status));
+	  g_warning ("%s", gsl_strerror (status));
 	  gsl_root_fsolver_free (s);
 	  return GSL_NAN;
 	}
