@@ -33,10 +33,14 @@
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
-#include <numcosmo/numcosmo.h>
+#include "build_cfg.h"
 
-#include <glib.h>
-#include <gsl/gsl_sf_erf.h>
+#include "lss/nc_cluster_abundance.h"
+#include "math/ncm_spline_cubic_notaknot.h"
+#include "math/ncm_spline2d_bicubic.h"
+#include "math/integral.h"
+#include "math/memory_pool.h"
+#include <gsl/gsl_histogram.h>
 
 enum
 {
@@ -66,7 +70,7 @@ static gdouble _N (NcClusterAbundance *cad, NcHICosmo *model) {g_error ("Functio
  * This function allocates memory for a new #NcClusterAbundance object and sets its properties to the values from
  * the input arguments.
  *
- * @Returns: A new #NcClusterAbundance.
+ * Returns: A new #NcClusterAbundance.
  */
 NcClusterAbundance *
 nc_cluster_abundance_new (NcMassFunction *mfp, NcHaloBiasFunc *mbiasf, NcClusterRedshift *clusterz, NcClusterMass *clusterm)
@@ -303,7 +307,7 @@ _nc_cluster_abundance_lnm_p_d2n_integrand (gdouble lnM, gpointer params)
   const gdouble d2NdzdlnM = nc_mass_function_d2n_dzdlnm (cad->mfp, obs_data->model, lnM, obs_data->z);
 
   //printf ("pM = % 20.8g d2NdzdlnM = % 20.8g res = % 20.8g\n", p_M_Mobs, d2NdzdlnM, p_M_Mobs * d2NdzdlnM);
-  
+
   return p_M_Mobs * d2NdzdlnM;
 }
 
@@ -589,15 +593,6 @@ nc_cluster_abundance_get_mass (NcClusterAbundance *cad)
  *
  * Returns: (transfer none): the value of #NcClusterAbundance:mass property.
  */
-#ifndef NUMCOSMO_HAVE_INLINE
-#define NUMCOSMO_HAVE_INLINE
-#undef _NC_CLUSTER_ABUNDANCE_INLINE_H_
-#define G_INLINE_FUNC
-#include "nc_cluster_abundance.h"
-#undef _NC_CLUSTER_ABUNDANCE_INLINE_H_
-#undef NUMCOSMO_HAVE_INLINE
-#endif /* NUMCOSMO_HAVE_INLINE */
-
 
 /**
  * nc_cluster_abundance_prepare:
@@ -1053,10 +1048,7 @@ nc_cluster_abundance_realizations_read_from_file (gchar *file_realization, gint
   long int file_position, goby;
 
   if (frealization == NULL)
-  {
-	fprintf (stderr, "abundance_random_generator_read_from_file: file %s, do not exist.\n", file_realization);
-	exit (0);
-  }
+    g_error ("abundance_random_generator_read_from_file: file %s, do not exist.", file_realization);
 
   file_position = ftell(frealization);
 
@@ -1076,10 +1068,7 @@ nc_cluster_abundance_realizations_read_from_file (gchar *file_realization, gint
 		continue;
 	  }
 	  if (n_enter ==1)
-	  {
-		fprintf (stderr, "Error, it must not exist just one 'enter'.\n");
-		exit(-1);
-	  }
+            g_error ("Error, it must not exist just one 'enter'.");
 	  n_enter = 0;
 	  z_total++;
 	}
@@ -1091,15 +1080,19 @@ nc_cluster_abundance_realizations_read_from_file (gchar *file_realization, gint
 	  for (i = 0; i < z_total; i++)
 	  {
 		gdouble z;
-		fscanf(frealization, "%lg\n", &z);
+		if (fscanf (frealization, "%lg\n", &z) < 1)
+		  g_error ("nc_cluster_abundance_realizations_read_from_file: io error");
 		//        printf ("%lg %u\n", z, z_total);
 		g_array_append_val(realization_z, z);
 	  }
 	  g_ptr_array_add (realizations, realization_z);
 	}
 
-	fscanf(frealization, " ");
-	fscanf(frealization, " ");
+	if (fscanf(frealization, " ") < 1)
+	  g_error ("nc_cluster_abundance_realizations_read_from_file: io error");
+	if (fscanf(frealization, " ") < 1)
+	  g_error ("nc_cluster_abundance_realizations_read_from_file: io error");
+
 	file_position = ftell(frealization);
   }
 
