@@ -33,18 +33,19 @@
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
-#include <numcosmo/numcosmo.h>
+#include "build_cfg.h"
+
+#include "lss/nc_data_cluster_abundance.h"
+#include "math/util.h"
+#include "math/ncm_func_eval.h"
+#include "math/ncm_cfg.h"
+#include "data/data_poisson.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <math.h>
-#include <glib.h>
-#include <gsl/gsl_integration.h>
-#include <gsl/gsl_const_mksa.h>
-#include <gsl/gsl_sf_erf.h>
-#include <gsl/gsl_histogram2d.h>
 #include <glib/gstdio.h>
+#include <gsl/gsl_randist.h>
+#ifdef NUMCOSMO_HAVE_CFITSIO
 #include <fitsio.h>
+#endif /* NUMCOSMO_HAVE_CFITSIO */
 
 static void
 _ca_data_copy (gpointer dest_ptr, gpointer src_ptr)
@@ -152,9 +153,6 @@ _ca_data_begin (gpointer ca_ptr)
 
 static guint _ca_data_get_length (gpointer ca_ptr) { return ((NcDataClusterAbundance *) ca_ptr)->np; }
 
-/**
- * FIXME
- */
 static NcDataStruct *
 _nc_data_struct_cluster_abundance_new ()
 {
@@ -294,14 +292,14 @@ _nc_data_cluster_abundance_unbinned_prepare (NcmMSet *mset, gpointer model, gpoi
 }
 
 /**
- * _nc_data_cluster_abundance_resample
- * @model: a #NcmModel.
+ * _nc_data_cluster_abundance_resample:
+ * @mset: a #NcmModel.
  * @model: FIXME
  * @data: FIXME
  *
  * This function generates random numbers which are used to obtain redshift
  * and mass (logarithm base e) values...
-   *
+ *
  */
 static void
 _nc_data_cluster_abundance_resample (NcmMSet *mset, gpointer model, gpointer data)
@@ -406,7 +404,7 @@ _nc_data_cluster_abundance_resample (NcmMSet *mset, gpointer model, gpointer dat
   }
 
   dca->np = NCM_MATRIX_NROWS (dca->z_obs);
-  printf ("# Generated %ld | expected % 20.15g\n", dca->np, nc_cluster_abundance_n (cad, NC_HICOSMO (ncm_mset_peek (mset, NC_HICOSMO_ID))));
+  //printf ("# Generated %ld | expected % 20.15g\n", dca->np, nc_cluster_abundance_n (cad, NC_HICOSMO (ncm_mset_peek (mset, NC_HICOSMO_ID))));
 
   g_free (zi_obs);
   g_free (zi_obs_params);
@@ -799,6 +797,8 @@ g_error ("FITS: %s", errormsg); \
 } \
 } while (FALSE);
 
+#ifdef NUMCOSMO_HAVE_CFITSIO
+
 /**
  * nc_cluster_abundance_catalog_save:
  * @data: a #NcData
@@ -888,9 +888,9 @@ nc_cluster_abundance_catalog_save (NcData *data, gchar *filename, gboolean overw
 	gchar *z_ser = ncm_cfg_serialize_to_string (G_OBJECT (dca->z), FALSE);
 	gchar *lnM_ser = ncm_cfg_serialize_to_string (G_OBJECT (dca->m), FALSE);
 
-	if (fits_write_key(fptr, TSTRING, "Z_OBJ", z_ser, "Serialized redshift object", &status))
+	if (fits_write_key_longstr (fptr, "Z_OBJ", z_ser, "Serialized redshift object", &status))
 	  NC_FITS_ERROR(status);
-	if (fits_write_key(fptr, TSTRING, "LNM_OBJ", lnM_ser, "Serialized mass object", &status))
+	if (fits_write_key_longstr (fptr, "LNM_OBJ", lnM_ser, "Serialized mass object", &status))
 	  NC_FITS_ERROR(status);
 
 	g_free (z_ser);
@@ -988,16 +988,19 @@ nc_cluster_abundance_catalog_load (NcData *data, gchar *filename)
 	nc_cluster_mass_free (dca->m);
 
   {
-	gchar z_ser[1024 * 10];
-	gchar lnM_ser[1024 * 10];
+	gchar *z_ser = NULL;
+	gchar *lnM_ser = NULL;
 
-	if (fits_read_key_str (fptr, "Z_OBJ", z_ser, comment, &status))
+	if (fits_read_key_longstr (fptr, "Z_OBJ", &z_ser, comment, &status))
 	  NC_FITS_ERROR (status);
-	if (fits_read_key_str (fptr, "LNM_OBJ", lnM_ser, comment, &status))
+	if (fits_read_key_longstr (fptr, "LNM_OBJ", &lnM_ser, comment, &status))
 	  NC_FITS_ERROR (status);
 
     dca->z = nc_cluster_redshift_new_from_name (z_ser);
     dca->m = nc_cluster_mass_new_from_name (lnM_ser);
+
+	g_free (z_ser);
+	g_free (lnM_ser);
   }
 
   {
@@ -1141,3 +1144,4 @@ nc_cluster_abundance_catalog_load (NcData *data, gchar *filename)
 
   return;
 }
+#endif /* NUMCOSMO_HAVE_CFITSIO */
