@@ -34,11 +34,15 @@
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
-#include <numcosmo/numcosmo.h>
+#include "build_cfg.h"
+
+#include "lss/nc_galaxy_acf.h"
+#include "lss/nc_window_tophat.h"
+#include "math/integral.h"
+#include "math/ncm_spline_cubic_notaknot.h"
 
 #include <gsl/gsl_sf_bessel.h>
 
-
 G_DEFINE_TYPE (NcGalaxyAcf, nc_galaxy_acf, G_TYPE_OBJECT);
 
 NcGalaxyAcf *
@@ -73,7 +77,7 @@ static gdouble
 ncm_galaxy_acf_psi_kernel_l (gdouble z, gpointer p)
 {
   NcmGalaxyAcfPsiKernel *apk = (NcmGalaxyAcfPsiKernel *) p;
-  const gdouble cd = NC_C_HUBBLE_RADIUS * nc_distance_comoving (apk->acf->dist, apk->model, z);
+  const gdouble cd = ncm_c_hubble_radius () * nc_distance_comoving (apk->acf->dist, apk->model, z);
   const gdouble Dz = nc_growth_func_eval (apk->acf->gf, apk->model, z);
   const gdouble fz = nc_growth_func_eval_deriv (apk->acf->gf, apk->model, z);
   const gdouble x = apk->k * cd;
@@ -87,7 +91,7 @@ static gdouble
 ncm_galaxy_acf_psi_kernel_lp1 (gdouble z, gpointer p)
 {
   NcmGalaxyAcfPsiKernel *apk = (NcmGalaxyAcfPsiKernel *) p;
-  const gdouble cd = NC_C_HUBBLE_RADIUS * nc_distance_comoving (apk->acf->dist, apk->model, z);
+  const gdouble cd = ncm_c_hubble_radius () * nc_distance_comoving (apk->acf->dist, apk->model, z);
   const gdouble Dz = nc_growth_func_eval (apk->acf->gf, apk->model, z);
   const gdouble fz = nc_growth_func_eval_deriv (apk->acf->gf, apk->model, z);
   const gdouble x = apk->k * cd;
@@ -100,7 +104,7 @@ static gdouble
 ncm_galaxy_acf_psi_kernel (gdouble z, gpointer p)
 {
   NcmGalaxyAcfPsiKernel *apk = (NcmGalaxyAcfPsiKernel *) p;
-  const gdouble cd = NC_C_HUBBLE_RADIUS * nc_distance_comoving (apk->acf->dist, apk->model, z);
+  const gdouble cd = ncm_c_hubble_radius () * nc_distance_comoving (apk->acf->dist, apk->model, z);
   const gdouble x = apk->k * cd;
   const gdouble x2 = x * x;
   const gdouble sel_func = 1.0;
@@ -145,7 +149,7 @@ ncm_galaxy_acf_psi (NcGalaxyAcf *acf, NcHICosmo *model, gdouble k, guint l)
 static gdouble
 ncm_galaxy_acf_psi_int (gdouble mu, gpointer p)
 {
-  static glong count = 0;
+//  static glong count = 0;
   NcmGalaxyAcfPsiKernel *apk = (NcmGalaxyAcfPsiKernel *) p;
   const gdouble k = exp (mu);
   const gdouble Pk = nc_transfer_func_matter_powerspectrum (apk->acf->tf, apk->model, k);
@@ -162,8 +166,8 @@ ncm_galaxy_acf_prepare_psi (NcGalaxyAcf *acf, NcHICosmo *model, guint l)
 {
   NcmGalaxyAcfPsiKernel psi_kernel;
   gsl_function F;
-  const gdouble sqrt_norma = nc_matter_var_sigma8_sqrtvar0 (acf->vp, model);
-  const gdouble norma = sqrt_norma * sqrt_norma;
+//  const gdouble sqrt_norma = nc_matter_var_sigma8_sqrtvar0 (acf->vp, model);
+//  const gdouble norma = sqrt_norma * sqrt_norma;
   F.function = &ncm_galaxy_acf_psi_int;
   F.params = &psi_kernel;
 
@@ -182,14 +186,14 @@ ncm_galaxy_acf_prepare_psi (NcGalaxyAcf *acf, NcHICosmo *model, guint l)
 	                        &res, &err);
 	//printf ("\n%u % 20.15g\n", l, norma * res);
 	fflush (stdout);
-	exit (0);
-	//return res;
+	//exit (0);
+	return;
   }
 
 /*
   ncm_spline_set_func (acf->s, NCM_SPLINE_FUNCTION_SPLINE, &F,
-                       log (1.0e-12 * NC_C_HUBBLE_RADIUS),
-                       log (1.0e1 * NC_C_HUBBLE_RADIUS),
+                       log (1.0e-12 * ncm_c_hubble_radius ()),
+                       log (1.0e1 * ncm_c_hubble_radius ()),
                        0, 1e-6);
 					   */
 }
