@@ -33,15 +33,13 @@
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
-#include <numcosmo/numcosmo.h>
+#include "build_cfg.h"
+
+#include "lss/nc_mass_function.h"
+#include "math/integral.h"
+#include "math/ncm_spline2d_bicubic.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <math.h>
-#include <glib.h>
 #include <gsl/gsl_integration.h>
-#include <gsl/gsl_const_mksa.h>
-#include <glib.h>
 
 enum
 {
@@ -486,8 +484,8 @@ gdouble
 nc_mass_function_dv_dzdomega (NcMassFunction *mfp, NcHICosmo *model, gdouble z)
 {
   const gdouble E = sqrt (nc_hicosmo_E2 (model, z));
-  gdouble dc = NC_C_HUBBLE_RADIUS * nc_distance_comoving (mfp->dist, model, z);
-  gdouble dV_dzdOmega = gsl_pow_2 (dc) * NC_C_HUBBLE_RADIUS / E;
+  gdouble dc = ncm_c_hubble_radius () * nc_distance_comoving (mfp->dist, model, z);
+  gdouble dV_dzdOmega = gsl_pow_2 (dc) * ncm_c_hubble_radius () / E;
   return dV_dzdOmega;
 }
 
@@ -646,7 +644,7 @@ _encapsulated_z (gdouble z, gpointer p)
   gdouble A = args->mfp->area_survey *
 	nc_mass_function_dv_dzdomega (args->mfp, args->model, z) *
 	nc_mass_function_dn_dlnm (args->mfp, args->model, args->lnM, z);
- 
+
   //printf ("z %.5g lnM %.5g d2N % 20.15g mf % 20.15g dV % 20.15g\n", z, args->lnM, A, nc_mass_function_dn_dlnm (args->mfp, args->model, args->lnM, z), nc_mass_function_dv_dzdomega (args->mfp, args->model, z));
   return A;
 
@@ -711,12 +709,4 @@ _nc_mass_function_generate_2Dspline_knots (NcMassFunction *mfp, NcHICosmo *model
  *
  * Returns: FIXME
  */
-#ifndef NUMCOSMO_HAVE_INLINE
-#define NUMCOSMO_HAVE_INLINE
-#undef _NC_MASS_FUNCTION_INLINE_H_
-#define G_INLINE_FUNC
-#include "nc_mass_function.h"
-#undef _NC_MASS_FUNCTION_INLINE_H_
-#undef NUMCOSMO_HAVE_INLINE
-#endif /* NUMCOSMO_HAVE_INLINE */
 
