@@ -34,28 +34,27 @@
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
-#include <numcosmo/numcosmo.h>
+#include "build_cfg.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <math.h>
-#include <glib.h>
-#include <gsl/gsl_math.h>
+#include "lss/nc_matter_var.h"
+#include "lss/nc_window_tophat.h"
+#include "lss/nc_window_gaussian.h"
+#include "nc_enum_types.h"
+#include "math/ncm_cfg.h"
+#include "math/integral.h"
+#include "math/ncm_spline_func.h"
+#include "math/ncm_spline_cubic_notaknot.h"
+
+#include <complex.h>
+#ifdef NUMCOSMO_HAVE_FFTW3
+#include <fftw3.h>
+#endif /* NUMCOSMO_HAVE_FFTW3 */
 #include <gsl/gsl_integration.h>
-#include <gsl/gsl_const_mksa.h>
-#include <gsl/gsl_chebyshev.h>
-#include <gsl/gsl_spline.h>
-#include <gsl/gsl_sf_expint.h>
-#include <gsl/gsl_sf_erf.h>
-#include <gsl/gsl_sf_bessel.h>
+#include <gsl/gsl_sf_result.h>
 #include <gsl/gsl_sf_gamma.h>
+#include <gsl/gsl_sf_bessel.h>
 #include <gsl/gsl_sf_trig.h>
-
-#include <cvodes/cvodes.h>
-#include <nvector/nvector_serial.h>
-#include <cvodes/cvodes_dense.h>
-#include <sundials/sundials_dense.h>
-#include <sundials/sundials_types.h>
+#include <gsl/gsl_sf_expint.h>
 
 #define NC_MATTER_VAR_SIGMA2_NP 150
 
@@ -282,7 +281,11 @@ nc_matter_var_prepare (NcMatterVar *vp, NcHICosmo *model)
 	  _nc_matter_var_prepare_splineint (vp, model);
 	  break;
 	case NC_MATTER_VAR_FFT:
+#ifdef NUMCOSMO_HAVE_FFTW3
 	  _nc_matter_var_prepare_fft (vp, model);
+#else
+          g_error ("nc_matter_var_prepare: Cannot use NC_MATTER_VAR_FFT: fftw not installed.");
+#endif
 	  break;
   }
 }
@@ -328,7 +331,7 @@ _nc_matter_var_over_growth2_gaussian (NcMatterVar *vp, NcHICosmo *model, gdouble
   ts.model = model;
 
   if (w == NULL)
-	w = gsl_integration_workspace_alloc (NC_INT_PARTITION);
+    w = gsl_integration_workspace_alloc (NC_INT_PARTITION);
 
   F.function = &_nc_matter_var_integrand_gaussian;
   F.params = &ts;
@@ -569,7 +572,7 @@ nc_matter_var_dlnvar0_dR (NcMatterVar *vp, NcHICosmo *model, gdouble lnR)
 }
 
 /**
- * nc_matter_var_dlnvar0_dR:
+ * nc_matter_var_dlnvar0_dlnR:
  * @vp: a #NcMatterVar.
  * @model: a #NcHICosmo.
  * @lnR: logarithm base e of the radius.
@@ -600,7 +603,7 @@ gdouble
 nc_matter_var_mass_to_R (NcMatterVar *vp, NcHICosmo *model, gdouble M)
 {
   const gdouble Omega_m = nc_hicosmo_Omega_m (model);
-  return cbrt (M / (Omega_m * nc_window_volume(vp->wp) * NC_C_CRIT_MASS_DENSITY_SOL_MPC));
+  return cbrt (M / (Omega_m * nc_window_volume(vp->wp) * ncm_c_crit_mass_density_solar_Mpc ()));
 }
 
 /**
@@ -617,7 +620,7 @@ gdouble
 nc_matter_var_R_to_mass (NcMatterVar *vp, NcHICosmo *model, gdouble R)
 {
   const gdouble Omega_m = nc_hicosmo_Omega_m (model);
-  return gsl_pow_3(R) * Omega_m * nc_window_volume(vp->wp) * NC_C_CRIT_MASS_DENSITY_SOL_MPC;
+  return gsl_pow_3(R) * Omega_m * nc_window_volume(vp->wp) * ncm_c_crit_mass_density_solar_Mpc ();
 }
 
 /**
@@ -634,7 +637,7 @@ gdouble
 nc_matter_var_lnM_to_lnR (NcMatterVar *vp, NcHICosmo *model, gdouble lnM)
 {
   const gdouble Omega_m = nc_hicosmo_Omega_m (model);
-  return (lnM - log (Omega_m * nc_window_volume(vp->wp) * NC_C_CRIT_MASS_DENSITY_SOL_MPC)) / 3.0;
+  return (lnM - log (Omega_m * nc_window_volume(vp->wp) * ncm_c_crit_mass_density_solar_Mpc ())) / 3.0;
 }
 
 /**
@@ -651,7 +654,7 @@ gdouble
 nc_matter_var_lnR_to_lnM (NcMatterVar *vp, NcHICosmo *model, gdouble lnR)
 {
   const gdouble Omega_m = nc_hicosmo_Omega_m (model);
-  return (3.0 * lnR + log (Omega_m * nc_window_volume(vp->wp) * NC_C_CRIT_MASS_DENSITY_SOL_MPC));
+  return (3.0 * lnR + log (Omega_m * nc_window_volume(vp->wp) * ncm_c_crit_mass_density_solar_Mpc ()));
 }
 
 /**
@@ -838,6 +841,7 @@ _nc_matter_var_prepare_splineint (NcMatterVar *vp, NcHICosmo *model)
   return;
 }
 
+#ifdef NUMCOSMO_HAVE_FFTW3
 static void
 _nc_matter_var_prepare_fft (NcMatterVar *vp, NcHICosmo *model)
 {
@@ -948,6 +952,7 @@ _nc_matter_var_prepare_fft (NcMatterVar *vp, NcHICosmo *model)
   ncm_spline_prepare (vp->sigma2_over_growth);
   ncm_spline_prepare (vp->deriv_sigma2_over_growth);
 }
+#endif /* NUMCOSMO_HAVE_FFTW3 */
 
 /**
  * _2f3:
