@@ -29,25 +29,16 @@
  * @short_description: Defines the prototype of the #NcTransferFunc object.
  *
  * This module comprises the set of functions to compute the transfer function and
- * derived quantities. See also <link linkend="sec_transf">Transfer Function</link>.
+ * derived quantities.
  */
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
-#include <numcosmo/numcosmo.h>
+#include "build_cfg.h"
 
-#include <glib.h>
-#include <glib/gprintf.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <math.h>
-#include <string.h>
-#include <gsl/gsl_integration.h>
-#include <gsl/gsl_sf_bessel.h>
-#include <gsl/gsl_spline.h>
-#include <gsl/gsl_errno.h>
-#include <gsl/gsl_matrix.h>
+#include "lss/nc_transfer_func.h"
+#include "math/ncm_cfg.h"
 
 G_DEFINE_ABSTRACT_TYPE (NcTransferFunc, nc_transfer_func, G_TYPE_OBJECT);
 
@@ -82,10 +73,7 @@ void
 nc_transfer_func_prepare (NcTransferFunc *tf, NcHICosmo *model)
 {
   if (tf->ctrl == NULL)
-  {
-    fprintf (stderr, "You should allocate a new tf using transfer_func_new_from_name(...)\n");
-    exit(0);
-  }
+    g_error ("You should allocate a new tf using transfer_func_new_from_name(...)");
 
   if (ncm_model_ctrl_update (tf->ctrl, NCM_MODEL(model)))
     NC_TRANSFER_FUNC_GET_CLASS (tf)->prepare (tf, model);
@@ -105,10 +93,7 @@ gdouble
 nc_transfer_func_eval (NcTransferFunc *tf, NcHICosmo *model, gdouble kh)
 {
   if (tf->ctrl == NULL)
-  {
-    fprintf (stderr, "You should allocate a new tf using transfer_func_new_from_name(...)\n");
-    exit(0);
-  }
+    g_error ("You should allocate a new tf using transfer_func_new_from_name(...)");
 
   if (ncm_model_ctrl_update (tf->ctrl, NCM_MODEL(model)))
     NC_TRANSFER_FUNC_GET_CLASS (tf)->prepare (tf, model);
@@ -130,10 +115,7 @@ gdouble
 nc_transfer_func_matter_powerspectrum (NcTransferFunc *tf, NcHICosmo *model, gdouble kh)
 {
   if (tf->ctrl == NULL)
-  {
-    fprintf (stderr, "You should allocate a new tf using transfer_func_new_from_name(...)\n");
-    exit(0);
-  }
+    g_error ("You should allocate a new tf using transfer_func_new_from_name(...)");
 
   if (ncm_model_ctrl_update (tf->ctrl, NCM_MODEL(model)))
     NC_TRANSFER_FUNC_GET_CLASS (tf)->prepare (tf, model);
