@@ -26,6 +26,10 @@
 #define _NC_FUNCTION_CACHE_H
 
 #include <glib.h>
+#include <glib-object.h>
+
+#include <numcosmo/nc_macros.h>
+#include <gsl/gsl_vector.h>
 
 G_BEGIN_DECLS
 
@@ -50,7 +54,7 @@ struct _NcFunctionCache
 {
   /*< private >*/
   GTree *tree;
-  GStaticMutex lock;
+  _NCM_MUTEX_TYPE lock;
   gboolean clear;
   guint n;
   gdouble abstol;
