@@ -30,20 +30,81 @@
  * FIXME
  */
 
+/**
+ * SECTION:nc_macros
+ * @title: Library Utilities Macros
+ * @short_description: FIXME
+ *
+ * FIXME
+ */
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
-#include <numcosmo/numcosmo.h>
+#include "build_cfg.h"
+
+#include "math/ncm_cfg.h"
+#include "math/ncm_spline_gsl.h"
+#include "math/ncm_spline_cubic.h"
+#include "math/ncm_spline_cubic_notaknot.h"
+#include "math/ncm_spline2d_bicubic.h"
+#include "math/ncm_spline2d_gsl.h"
+#include "math/ncm_spline2d_spline.h"
+#include "math/ncm_model.h"
+#include "math/ncm_model_ctrl.h"
+#include "math/ncm_reparam_linear.h"
+#include "model/nc_hicosmo_qconst.h"
+#include "model/nc_hicosmo_qlinear.h"
+#include "model/nc_hicosmo_qpw.h"
+#include "model/nc_hicosmo_qspline.h"
+#include "model/nc_hicosmo_lcdm.h"
+#include "model/nc_hicosmo_de_xcdm.h"
+#include "model/nc_hicosmo_de_linder.h"
+#include "model/nc_hicosmo_de_pad.h"
+#include "model/nc_hicosmo_de_qe.h"
+#include "lss/nc_window_tophat.h"
+#include "lss/nc_window_gaussian.h"
+#include "lss/nc_growth_func.h"
+#include "lss/nc_transfer_func.h"
+#include "lss/nc_transfer_func_bbks.h"
+#include "lss/nc_transfer_func_eh.h"
+#include "lss/nc_transfer_func_camb.h"
+#include "lss/nc_transfer_func_pert.h"
+#include "lss/nc_matter_var.h"
+#include "lss/nc_multiplicity_func.h"
+#include "lss/nc_multiplicity_func_st.h"
+#include "lss/nc_multiplicity_func_ps.h"
+#include "lss/nc_multiplicity_func_jenkins.h"
+#include "lss/nc_multiplicity_func_warren.h"
+#include "lss/nc_multiplicity_func_tinker.h"
+#include "lss/nc_multiplicity_func_tinker_mean.h"
+#include "lss/nc_multiplicity_func_tinker_crit.h"
+#include "lss/nc_mass_function.h"
+#include "lss/nc_galaxy_acf.h"
+#include "lss/nc_cluster_mass.h"
+#include "lss/nc_cluster_mass_nodist.h"
+#include "lss/nc_cluster_mass_lnnormal.h"
+#include "lss/nc_cluster_mass_vanderlinde.h"
+#include "lss/nc_cluster_mass_benson.h"
+#include "lss/nc_cluster_mass_benson_xray.h"
+#include "lss/nc_cluster_redshift.h"
+#include "lss/nc_cluster_redshift_nodist.h"
+#include "lss/nc_cluster_photoz_gauss_global.h"
+#include "lss/nc_cluster_photoz_gauss.h"
+#include "lss/nc_halo_bias_func.h"
+#include "lss/nc_halo_bias_type_ps.h"
+#include "lss/nc_halo_bias_type_st_ellip.h"
+#include "lss/nc_halo_bias_type_st_spher.h"
+#include "lss/nc_halo_bias_type_tinker.h"
+#include "lss/nc_cluster_abundance.h"
+#include "nc_distance.h"
+#include "nc_recomb.h"
+#include "nc_recomb_seager.h"
 
-#include <string.h>
-#include <glib-object.h>
-#include <glib.h>
 #include <gio/gio.h>
-#include <glib/gstdio.h>
-#ifdef NUMCOSMO_HAVE_SQLITE3
-#include <sqlite3.h>
-#endif
+#ifdef NUMCOSMO_HAVE_FFTW3
+#include <fftw3.h>
+#endif /* NUMCOSMO_HAVE_FFTW3 */
 
 static gchar *numcosmo_path = NULL;
 static gboolean numcosmo_init = FALSE;
@@ -58,7 +119,7 @@ _ncm_cfg_log_message (const gchar *log_domain, GLogLevelFlags log_level, const g
 {
   if (_enable_msg && _log_stream)
   {
-	fprintf (_log_stream, message);
+	fprintf (_log_stream, "%s", message);
 	if (_enable_msg_flush)
 	  fflush (_log_stream);
   }
@@ -81,7 +142,9 @@ ncm_cfg_init (void)
 	g_mkdir_with_parents (numcosmo_path, 0755);
 
   gsl_err = gsl_set_error_handler_off ();
+#if (GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 32)
   g_thread_init (NULL);
+#endif
   g_type_init();
 
   g_setenv ("CUBACORES", "0", TRUE);
@@ -89,80 +152,85 @@ ncm_cfg_init (void)
   _log_msg_id = g_log_set_handler (G_LOG_DOMAIN, G_LOG_LEVEL_MESSAGE | G_LOG_LEVEL_DEBUG, _ncm_cfg_log_message, NULL);
   _log_stream = stdout;
 
-  ncm_cfg_register_model (NCM_TYPE_SPLINE);
-  ncm_cfg_register_model (NCM_TYPE_SPLINE_CUBIC);
-  ncm_cfg_register_model (NCM_TYPE_SPLINE_CUBIC_NOTAKNOT);
-  ncm_cfg_register_model (NCM_TYPE_SPLINE_GSL);
+  ncm_cfg_register_obj (NCM_TYPE_SPLINE);
+  ncm_cfg_register_obj (NCM_TYPE_SPLINE_CUBIC);
+  ncm_cfg_register_obj (NCM_TYPE_SPLINE_CUBIC_NOTAKNOT);
+  ncm_cfg_register_obj (NCM_TYPE_SPLINE_GSL);
 
-  ncm_cfg_register_model (NCM_TYPE_SPLINE2D);
-  ncm_cfg_register_model (NCM_TYPE_SPLINE2D_BICUBIC);
-  ncm_cfg_register_model (NCM_TYPE_SPLINE2D_GSL);
-  ncm_cfg_register_model (NCM_TYPE_SPLINE2D_SPLINE);
+  ncm_cfg_register_obj (NCM_TYPE_SPLINE2D);
+  ncm_cfg_register_obj (NCM_TYPE_SPLINE2D_BICUBIC);
+  ncm_cfg_register_obj (NCM_TYPE_SPLINE2D_GSL);
+  ncm_cfg_register_obj (NCM_TYPE_SPLINE2D_SPLINE);
 
-  ncm_cfg_register_model (NCM_TYPE_MODEL);
-  ncm_cfg_register_model (NCM_TYPE_MODEL_CTRL);
+  ncm_cfg_register_obj (NCM_TYPE_MODEL);
+  ncm_cfg_register_obj (NCM_TYPE_MODEL_CTRL);
 
-  ncm_cfg_register_model (NCM_TYPE_REPARAM);
-  ncm_cfg_register_model (NCM_TYPE_REPARAM_LINEAR);
+  ncm_cfg_register_obj (NCM_TYPE_REPARAM);
+  ncm_cfg_register_obj (NCM_TYPE_REPARAM_LINEAR);
 
-  ncm_cfg_register_model (NC_TYPE_HICOSMO_QCONST);
-  ncm_cfg_register_model (NC_TYPE_HICOSMO_QLINEAR);
-  ncm_cfg_register_model (NC_TYPE_HICOSMO_QPW);
-  ncm_cfg_register_model (NC_TYPE_HICOSMO_QSPLINE);
-  ncm_cfg_register_model (NC_TYPE_HICOSMO_LCDM);
-  ncm_cfg_register_model (NC_TYPE_HICOSMO_DE_XCDM);
-  ncm_cfg_register_model (NC_TYPE_HICOSMO_DE_LINDER);
-  ncm_cfg_register_model (NC_TYPE_HICOSMO_DE_PAD);
-  ncm_cfg_register_model (NC_TYPE_HICOSMO_DE_QE);
+  ncm_cfg_register_obj (NC_TYPE_HICOSMO_QCONST);
+  ncm_cfg_register_obj (NC_TYPE_HICOSMO_QLINEAR);
+  ncm_cfg_register_obj (NC_TYPE_HICOSMO_QPW);
+  ncm_cfg_register_obj (NC_TYPE_HICOSMO_QSPLINE);
+  ncm_cfg_register_obj (NC_TYPE_HICOSMO_LCDM);
+  ncm_cfg_register_obj (NC_TYPE_HICOSMO_DE_XCDM);
+  ncm_cfg_register_obj (NC_TYPE_HICOSMO_DE_LINDER);
+  ncm_cfg_register_obj (NC_TYPE_HICOSMO_DE_PAD);
+  ncm_cfg_register_obj (NC_TYPE_HICOSMO_DE_QE);
 
-  ncm_cfg_register_model (NC_TYPE_WINDOW);
-  ncm_cfg_register_model (NC_TYPE_WINDOW_TOPHAT);
-  ncm_cfg_register_model (NC_TYPE_WINDOW_GAUSSIAN);
+  ncm_cfg_register_obj (NC_TYPE_WINDOW);
+  ncm_cfg_register_obj (NC_TYPE_WINDOW_TOPHAT);
+  ncm_cfg_register_obj (NC_TYPE_WINDOW_GAUSSIAN);
 
-  ncm_cfg_register_model (NC_TYPE_GROWTH_FUNC);
+  ncm_cfg_register_obj (NC_TYPE_GROWTH_FUNC);
 
-  ncm_cfg_register_model (NC_TYPE_TRANSFER_FUNC);
-  ncm_cfg_register_model (NC_TYPE_TRANSFER_FUNC_BBKS);
-  ncm_cfg_register_model (NC_TYPE_TRANSFER_FUNC_EH);
-  ncm_cfg_register_model (NC_TYPE_TRANSFER_FUNC_CAMB);
-  ncm_cfg_register_model (NC_TYPE_TRANSFER_FUNC_PERT);
+  ncm_cfg_register_obj (NC_TYPE_TRANSFER_FUNC);
+  ncm_cfg_register_obj (NC_TYPE_TRANSFER_FUNC_BBKS);
+  ncm_cfg_register_obj (NC_TYPE_TRANSFER_FUNC_EH);
+  ncm_cfg_register_obj (NC_TYPE_TRANSFER_FUNC_CAMB);
+  ncm_cfg_register_obj (NC_TYPE_TRANSFER_FUNC_PERT);
 
-  ncm_cfg_register_model (NC_TYPE_MATTER_VAR);
+  ncm_cfg_register_obj (NC_TYPE_MATTER_VAR);
 
-  ncm_cfg_register_model (NC_TYPE_MULTIPLICITY_FUNC);
-  ncm_cfg_register_model (NC_TYPE_MULTIPLICITY_FUNC_PS);
-  ncm_cfg_register_model (NC_TYPE_MULTIPLICITY_FUNC_ST);
-  ncm_cfg_register_model (NC_TYPE_MULTIPLICITY_FUNC_JENKINS);
-  ncm_cfg_register_model (NC_TYPE_MULTIPLICITY_FUNC_WARREN);
-  ncm_cfg_register_model (NC_TYPE_MULTIPLICITY_FUNC_TINKER);
-  ncm_cfg_register_model (NC_TYPE_MULTIPLICITY_FUNC_TINKER_MEAN);
-  ncm_cfg_register_model (NC_TYPE_MULTIPLICITY_FUNC_TINKER_CRIT);
+  ncm_cfg_register_obj (NC_TYPE_MULTIPLICITY_FUNC);
+  ncm_cfg_register_obj (NC_TYPE_MULTIPLICITY_FUNC_PS);
+  ncm_cfg_register_obj (NC_TYPE_MULTIPLICITY_FUNC_ST);
+  ncm_cfg_register_obj (NC_TYPE_MULTIPLICITY_FUNC_JENKINS);
+  ncm_cfg_register_obj (NC_TYPE_MULTIPLICITY_FUNC_WARREN);
+  ncm_cfg_register_obj (NC_TYPE_MULTIPLICITY_FUNC_TINKER);
+  ncm_cfg_register_obj (NC_TYPE_MULTIPLICITY_FUNC_TINKER_MEAN);
+  ncm_cfg_register_obj (NC_TYPE_MULTIPLICITY_FUNC_TINKER_CRIT);
 
-  ncm_cfg_register_model (NC_TYPE_MASS_FUNCTION);
+  ncm_cfg_register_obj (NC_TYPE_MASS_FUNCTION);
 
-  ncm_cfg_register_model (NC_TYPE_GALAXY_ACF);
+  ncm_cfg_register_obj (NC_TYPE_GALAXY_ACF);
 
-  ncm_cfg_register_model (NC_TYPE_CLUSTER_MASS);
-  ncm_cfg_register_model (NC_TYPE_CLUSTER_MASS_NODIST);
-  ncm_cfg_register_model (NC_TYPE_CLUSTER_MASS_LNNORMAL);
-  ncm_cfg_register_model (NC_TYPE_CLUSTER_MASS_VANDERLINDE);
-  ncm_cfg_register_model (NC_TYPE_CLUSTER_MASS_BENSON);
-  ncm_cfg_register_model (NC_TYPE_CLUSTER_MASS_BENSON_XRAY);
+  ncm_cfg_register_obj (NC_TYPE_CLUSTER_MASS);
+  ncm_cfg_register_obj (NC_TYPE_CLUSTER_MASS_NODIST);
+  ncm_cfg_register_obj (NC_TYPE_CLUSTER_MASS_LNNORMAL);
+  ncm_cfg_register_obj (NC_TYPE_CLUSTER_MASS_VANDERLINDE);
+  ncm_cfg_register_obj (NC_TYPE_CLUSTER_MASS_BENSON);
+  ncm_cfg_register_obj (NC_TYPE_CLUSTER_MASS_BENSON_XRAY);
 
-  ncm_cfg_register_model (NC_TYPE_CLUSTER_REDSHIFT);
-  ncm_cfg_register_model (NC_TYPE_CLUSTER_REDSHIFT_NODIST);
-  ncm_cfg_register_model (NC_TYPE_CLUSTER_PHOTOZ_GAUSS_GLOBAL);
-  ncm_cfg_register_model (NC_TYPE_CLUSTER_PHOTOZ_GAUSS);
+  ncm_cfg_register_obj (NC_TYPE_CLUSTER_REDSHIFT);
+  ncm_cfg_register_obj (NC_TYPE_CLUSTER_REDSHIFT_NODIST);
+  ncm_cfg_register_obj (NC_TYPE_CLUSTER_PHOTOZ_GAUSS_GLOBAL);
+  ncm_cfg_register_obj (NC_TYPE_CLUSTER_PHOTOZ_GAUSS);
 
-  ncm_cfg_register_model (NC_TYPE_HALO_BIAS_FUNC);
+  ncm_cfg_register_obj (NC_TYPE_HALO_BIAS_FUNC);
 
-  ncm_cfg_register_model (NC_TYPE_HALO_BIAS_TYPE);
-  ncm_cfg_register_model (NC_TYPE_HALO_BIAS_TYPE_PS);
-  ncm_cfg_register_model (NC_TYPE_HALO_BIAS_TYPE_ST_ELLIP);
-  ncm_cfg_register_model (NC_TYPE_HALO_BIAS_TYPE_ST_SPHER);
-  ncm_cfg_register_model (NC_TYPE_HALO_BIAS_TYPE_TINKER);
+  ncm_cfg_register_obj (NC_TYPE_HALO_BIAS_TYPE);
+  ncm_cfg_register_obj (NC_TYPE_HALO_BIAS_TYPE_PS);
+  ncm_cfg_register_obj (NC_TYPE_HALO_BIAS_TYPE_ST_ELLIP);
+  ncm_cfg_register_obj (NC_TYPE_HALO_BIAS_TYPE_ST_SPHER);
+  ncm_cfg_register_obj (NC_TYPE_HALO_BIAS_TYPE_TINKER);
 
-  ncm_cfg_register_model (NC_TYPE_CLUSTER_ABUNDANCE);
+  ncm_cfg_register_obj (NC_TYPE_CLUSTER_ABUNDANCE);
+
+	ncm_cfg_register_obj (NC_TYPE_DISTANCE);
+
+	ncm_cfg_register_obj (NC_TYPE_RECOMB);
+	ncm_cfg_register_obj (NC_TYPE_RECOMB_SEAGER);
 
   numcosmo_init = TRUE;
   return;
@@ -183,22 +251,16 @@ ncm_cfg_enable_gsl_err_handler (void)
 static uint nreg_model = 0;
 
 /**
- * ncm_cfg_register_model:
- * @model: FIXME
+ * ncm_cfg_register_obj:
+ * @obj: FIXME
  *
  * FIXME
  */
 void
-ncm_cfg_register_model (GType model)
+ncm_cfg_register_obj (GType obj)
 {
-#ifdef NCM_DEBUG_MSGS
-  GType model_type = NCM_TYPE_MODEL;
-  GType model_type = g_type_next_base (model, model_type);
-  g_message ("# %s: %s:%s registred\n",
-             g_type_name (model_type),
-             g_type_name (model_type),
-             g_type_name (model));
-#endif /* NCM_DEBUG_MSGS */
+  gpointer obj_class = g_type_class_ref (obj);
+  g_type_class_unref (obj_class);
   nreg_model++;
 }
 
@@ -215,10 +277,7 @@ ncm_cfg_set_logfile (gchar *filename)
   if (out != NULL)
 	_log_stream = out;
   else
-  {
-	fprintf (stderr, "ncm_cfg_set_logfile: Can't open logfile (%s)\n", filename);
-	exit (-1);
-  }
+    g_error ("ncm_cfg_set_logfile: Can't open logfile (%s)", filename);
 }
 
 /**
@@ -326,16 +385,13 @@ ncm_cfg_keyfile_to_arg (GKeyFile *kfile, gchar *group_name, GOptionEntry *entrie
 }
 
 /**
- * ncm_cfg_keyfile_to_arg:
+ * ncm_cfg_entries_to_keyfile:
  * @kfile: FIXME
  * @group_name: FIXME
  * @entries: FIXME
- * @argv: FIXME
- * @argc: FIXME
  *
  * FIXME
  *
- * Returns: FIXME
  */
 void
 ncm_cfg_entries_to_keyfile (GKeyFile *kfile, gchar *group_name, GOptionEntry *entries)
@@ -344,6 +400,7 @@ ncm_cfg_entries_to_keyfile (GKeyFile *kfile, gchar *group_name, GOptionEntry *en
   gint i;
   for (i = 0; entries[i].long_name != NULL; i++)
   {
+	gboolean skip_comment = FALSE;
 	switch (entries[i].arg)
 	{
 	  case G_OPTION_ARG_NONE:
@@ -378,8 +435,12 @@ ncm_cfg_entries_to_keyfile (GKeyFile *kfile, gchar *group_name, GOptionEntry *en
 	  }
 	  case G_OPTION_ARG_INT64:
 	  {
+#if !((GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 26))
 		gint64 arg_l = ((gint64 *)entries[i].arg_data)[0];
 		g_key_file_set_int64 (kfile, group_name, entries[i].long_name, arg_l);
+#else
+		g_error ("ncm_cfg_entries_to_keyfile: gint64 not supported, recompile "PACKAGE_NAME" with glib >= 2.26");
+#endif
 		break;
 	  }
 	  case G_OPTION_ARG_DOUBLE:
@@ -389,10 +450,15 @@ ncm_cfg_entries_to_keyfile (GKeyFile *kfile, gchar *group_name, GOptionEntry *en
 		break;
 	  }
 	  default:
+		skip_comment = TRUE;
 		//g_error ("ncm_cfg_entries_to_keyfile: cannot convert entry type %d to keyfile", entries[i].arg);
 		break;
 	}
-	g_key_file_set_comment (kfile, group_name, entries[i].long_name, entries[i].description, &error);
+	if (!skip_comment)
+	{
+	  if (!g_key_file_set_comment (kfile, group_name, entries[i].long_name, entries[i].description, &error))
+		g_error ("ncm_cfg_entries_to_keyfile: %s", error->message);
+	}
   }
 }
 
@@ -1106,6 +1172,7 @@ ncm_cfg_command_line (gchar *argv[], gint argc)
  */
 GObject *
 ncm_cfg_create_from_string (const gchar *obj_ser)
+#if !((GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 30))
 {
   GError *error = NULL;
   static gsize regex_init = FALSE;
@@ -1163,6 +1230,12 @@ ncm_cfg_create_from_string (const gchar *obj_ser)
 
   return obj;
 }
+#else
+{
+  g_error ("ncm_cfg_create_from_string: serialization not supported, recompile "PACKAGE_NAME" with glib >= 2.30");
+  return NULL;
+}
+#endif
 
 /**
  * ncm_cfg_create_from_name_params:
@@ -1175,6 +1248,7 @@ ncm_cfg_create_from_string (const gchar *obj_ser)
  */
 GObject *
 ncm_cfg_create_from_name_params (const gchar *obj_name, GVariant *params)
+#if !((GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 30))
 {
   GObject *obj = NULL;
   GType gtype = g_type_from_name (obj_name);
@@ -1233,7 +1307,14 @@ ncm_cfg_create_from_name_params (const gchar *obj_name, GVariant *params)
 
   return obj;
 }
+#else
+{
+  g_error ("ncm_cfg_create_from_name_params: serialization not supported, recompile "PACKAGE_NAME" with glib >= 2.30");
+  return NULL;
+}
+#endif
 
+#if !((GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 30))
 static const GVariantType *
 _ncm_cfg_gtype_to_gvariant_type (GType t)
 {
@@ -1260,7 +1341,7 @@ _ncm_cfg_gtype_to_gvariant_type (GType t)
 		  return G_VARIANT_TYPE_INT64;
 		  break;
 		default:
-		  g_error ("Unknown gint size %lu\n", sizeof(gint));
+		  g_error ("Unknown gint size %"G_GSIZE_FORMAT"\n", sizeof(gint));
 		  break;
 	  }
 	  break;
@@ -1279,7 +1360,7 @@ _ncm_cfg_gtype_to_gvariant_type (GType t)
 		  return G_VARIANT_TYPE_UINT64;
 		  break;
 		default:
-		  g_error ("Unknown gint size %lu\n", sizeof(guint));
+		  g_error ("Unknown gint size %"G_GSIZE_FORMAT"\n", sizeof(guint));
 		  break;
 	  }
 	  break;
@@ -1298,7 +1379,7 @@ _ncm_cfg_gtype_to_gvariant_type (GType t)
 		  return G_VARIANT_TYPE_INT64;
 		  break;
 		default:
-		  g_error ("Unknown gint size %lu\n", sizeof(glong));
+		  g_error ("Unknown gint size %"G_GSIZE_FORMAT"\n", sizeof(glong));
 		  break;
 	  }
 	  break;
@@ -1317,7 +1398,7 @@ _ncm_cfg_gtype_to_gvariant_type (GType t)
 		  return G_VARIANT_TYPE_UINT64;
 		  break;
 		default:
-		  g_error ("Unknown gint size %lu\n", sizeof(gulong));
+		  g_error ("Unknown gint size %"G_GSIZE_FORMAT"\n", sizeof(gulong));
 		  break;
 	  }
 	  break;
@@ -1343,6 +1424,7 @@ _ncm_cfg_gtype_to_gvariant_type (GType t)
 	  break;
   }
 }
+#endif
 
 /**
  * ncm_cfg_gvalue_to_gvariant:
@@ -1354,6 +1436,7 @@ _ncm_cfg_gtype_to_gvariant_type (GType t)
  */
 GVariant *
 ncm_cfg_gvalue_to_gvariant (GValue *val)
+#if !((GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 30))
 {
   GType t = G_VALUE_TYPE (val);
   GType fund_t = G_TYPE_FUNDAMENTAL (t);
@@ -1387,6 +1470,12 @@ ncm_cfg_gvalue_to_gvariant (GValue *val)
 
   return var;
 }
+#else
+{
+  g_error ("ncm_cfg_gvalue_to_gvariant: serialization not supported, recompile "PACKAGE_NAME" with glib >= 2.30");
+  return NULL;
+}
+#endif
 
 /**
  * ncm_cfg_serialize_to_variant:
@@ -1398,6 +1487,7 @@ ncm_cfg_gvalue_to_gvariant (GValue *val)
  */
 GVariant *
 ncm_cfg_serialize_to_variant (GObject *obj)
+#if !((GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 30))
 {
   const gchar *obj_name = G_OBJECT_TYPE_NAME (obj);
   GObjectClass *klass = G_OBJECT_GET_CLASS (obj);
@@ -1446,6 +1536,12 @@ ncm_cfg_serialize_to_variant (GObject *obj)
 	return ser_var;
   }
 }
+#else
+{
+  g_error ("ncm_cfg_serialize_to_variant: serialization not supported, recompile "PACKAGE_NAME" with glib >= 2.30");
+  return NULL;
+}
+#endif
 
 /**
  * ncm_cfg_serialize_to_string:
@@ -1459,6 +1555,7 @@ ncm_cfg_serialize_to_variant (GObject *obj)
  */
 gchar *
 ncm_cfg_serialize_to_string (GObject *obj, gboolean valid_variant)
+#if !((GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 30))
 {
   GVariant *ser_var = ncm_cfg_serialize_to_variant (obj);
   gchar *ser = NULL;
@@ -1487,3 +1584,9 @@ ncm_cfg_serialize_to_string (GObject *obj, gboolean valid_variant)
   g_variant_unref (ser_var);
   return ser;
 }
+#else
+{
+  g_error ("ncm_cfg_serialize_to_string: serialization not supported, recompile "PACKAGE_NAME" with glib >= 2.30");
+  return NULL;
+}
+#endif
