@@ -26,15 +26,23 @@
 #define _NCM_CFG_H
 
 #include <glib.h>
+#include <glib/gstdio.h>
+#include <glib-object.h>
+#include <stdio.h>
+#include <gsl/gsl_vector.h>
+#include <gsl/gsl_matrix.h>
+#include <gsl/gsl_spline.h>
 #ifdef NUMCOSMO_HAVE_SQLITE3
 #include <sqlite3.h>
 #endif
+#include <numcosmo/math/ncm_spline.h>
+
 
 G_BEGIN_DECLS
 
 void ncm_cfg_init (void);
 void ncm_cfg_enable_gsl_err_handler (void);
-void ncm_cfg_register_model (GType model);
+void ncm_cfg_register_obj (GType obj);
 gchar *ncm_cfg_get_fullpath (gchar *filename, ...);
 void ncm_cfg_keyfile_to_arg (GKeyFile *kfile, gchar *group_name, GOptionEntry *entries, gchar **argv, gint *argc);
 void ncm_cfg_entries_to_keyfile (GKeyFile *kfile, gchar *group_name, GOptionEntry *entries);
@@ -84,21 +92,21 @@ typedef union _NcmDoubleInt64
   gdouble x;
 } NcmDoubleInt64;
 
-#define NCM_WRITE_INT32(_ff,_ii) do { gint32 _temp_i = GINT32_TO_BE ((_ii)); fwrite (&_temp_i, sizeof(gint32), (1), _ff); } while (FALSE)
-#define NCM_WRITE_UINT32(_ff,_ii) do { guint32 _temp_i = GUINT32_TO_BE ((_ii)); fwrite (&_temp_i, sizeof(guint32), (1), _ff); } while (FALSE)
+#define NCM_WRITE_INT32(_ff,_ii) do { gint32 _temp_i = GINT32_TO_BE ((_ii)); if (fwrite (&_temp_i, sizeof(gint32), (1), _ff) != 1) g_error ("NCM_WRITE_INT32: io error"); } while (FALSE)
+#define NCM_WRITE_UINT32(_ff,_ii) do { guint32 _temp_i = GUINT32_TO_BE ((_ii)); if (fwrite (&_temp_i, sizeof(guint32), (1), _ff) != 1) g_error ("NCM_WRITE_UINT32: io error"); } while (FALSE)
 
-#define NCM_WRITE_INT64(_ff,_ii) do { gint64 _temp_i = GINT64_TO_BE ((_ii)); fwrite (&_temp_i, sizeof(gint64), (1), _ff); } while (FALSE)
-#define NCM_WRITE_UINT64(_ff,_ii) do { guint64 _temp_i = GUINT64_TO_BE ((_ii)); fwrite (&_temp_i, sizeof(guint64), (1), _ff); } while (FALSE)
+#define NCM_WRITE_INT64(_ff,_ii) do { gint64 _temp_i = GINT64_TO_BE ((_ii)); if (fwrite (&_temp_i, sizeof(gint64), (1), _ff) != 1) g_error ("NCM_WRITE_INT64: io error"); } while (FALSE)
+#define NCM_WRITE_UINT64(_ff,_ii) do { guint64 _temp_i = GUINT64_TO_BE ((_ii)); if (fwrite (&_temp_i, sizeof(guint64), (1), _ff) != 1) g_error ("NCM_WRITE_INT64: io error"); } while (FALSE)
 
-#define NCM_WRITE_DOUBLE(_ff,_ii) do { NcmDoubleInt64 _iii; _iii.x = _ii; _iii.i = GINT64_TO_BE ((_iii.i)); fwrite (&_iii.i, sizeof(gint64), (1), _ff); } while (FALSE)
+#define NCM_WRITE_DOUBLE(_ff,_ii) do { NcmDoubleInt64 _iii; _iii.x = _ii; _iii.i = GINT64_TO_BE ((_iii.i)); if (fwrite (&_iii.i, sizeof(gint64), (1), _ff) != 1) g_error ("NCM_WRITE_DOUBLE: io error"); } while (FALSE)
 
-#define NCM_READ_INT32(_ff,_ii) do { gint32 _temp_i; fread (&_temp_i, sizeof(gint32), (1), _ff); _ii = GINT32_FROM_BE (_temp_i); } while (FALSE)
-#define NCM_READ_UINT32(_ff,_ii) do { guint32 _temp_i; fread (&_temp_i, sizeof(guint32), (1), _ff); _ii = GUINT32_FROM_BE (_temp_i); } while (FALSE)
+#define NCM_READ_INT32(_ff,_ii) do { gint32 _temp_i; if (fread (&_temp_i, sizeof(gint32), (1), _ff) != 1) g_error ("NCM_READ_INT32: io error"); _ii = GINT32_FROM_BE (_temp_i); } while (FALSE)
+#define NCM_READ_UINT32(_ff,_ii) do { guint32 _temp_i; if (fread (&_temp_i, sizeof(guint32), (1), _ff) != 1) g_error ("NCM_READ_UINT32: io error"); _ii = GUINT32_FROM_BE (_temp_i); } while (FALSE)
 
-#define NCM_READ_INT64(_ff,_ii) do { gint64 _temp_i; fread (&_temp_i, sizeof(gint64), (1), _ff); _ii = GINT64_FROM_BE (_temp_i); } while (FALSE)
-#define NCM_READ_UINT64(_ff,_ii) do { guint64 _temp_i; fread (&_temp_i, sizeof(guint64), (1), _ff); _ii = GUINT64_FROM_BE (_temp_i); } while (FALSE)
+#define NCM_READ_INT64(_ff,_ii) do { gint64 _temp_i; if (fread (&_temp_i, sizeof(gint64), (1), _ff) != 1) g_error ("NCM_READ_INT64: io error"); _ii = GINT64_FROM_BE (_temp_i); } while (FALSE)
+#define NCM_READ_UINT64(_ff,_ii) do { guint64 _temp_i; if (fread (&_temp_i, sizeof(guint64), (1), _ff) != 1) g_error ("NCM_READ_UINT64: io error"); _ii = GUINT64_FROM_BE (_temp_i); } while (FALSE)
 
-#define NCM_READ_DOUBLE(_ff,_ii) do { NcmDoubleInt64 _iii; fread (&_iii.i, sizeof(gint64), (1), _ff); _iii.i = GINT64_FROM_BE (_iii.i); _ii = _iii.x; } while (FALSE)
+#define NCM_READ_DOUBLE(_ff,_ii) do { NcmDoubleInt64 _iii; if (fread (&_iii.i, sizeof(gint64), (1), _ff) != 1) g_error ("NCM_READ_DOUBLE: io error"); _iii.i = GINT64_FROM_BE (_iii.i); _ii = _iii.x; } while (FALSE)
 
 gchar *ncm_cfg_command_line (gchar *argv[], gint argc);
 
