@@ -26,8 +26,15 @@
 #ifndef _NCM_FFTLOG_H_
 #define _NCM_FFTLOG_H_
 
+#include <glib.h>
 #include <glib-object.h>
 
+#ifndef NUMCOSMO_GIR_SCAN
+#ifdef NUMCOSMO_HAVE_FFTW3
+#include <fftw3.h>
+#endif /* NUMCOSMO_HAVE_FFTW3 */
+#endif
+
 G_BEGIN_DECLS
 
 #define NCM_TYPE_FFTLOG             (ncm_fftlog_get_type ())
@@ -56,10 +63,12 @@ struct _NcmFftlog
   gdouble lnr0;
   gdouble L;
   gdouble dr;
+#ifdef NUMCOSMO_HAVE_FFTW3
   fftw_complex *in;
   fftw_complex *out;
   fftw_plan p_in2out;
   fftw_plan p_out2in;
+#endif /* NUMCOSMO_HAVE_FFTW3 */
 };
 
 GType ncm_fftlog_get_type (void) G_GNUC_CONST;
