@@ -33,7 +33,10 @@
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
-#include <numcosmo/numcosmo.h>
+#include "build_cfg.h"
+
+#include "math/ncm_model.h"
+#include "math/ncm_mset.h"
 
 enum
 {
@@ -445,7 +448,7 @@ ncm_model_class_init (NcmModelClass *klass)
 G_LOCK_DEFINE_STATIC (last_model_id);
 
 void
-ncm_model_register_id (NcmModelClass *model_class)
+ncm_model_class_register_id (NcmModelClass *model_class)
 {
   if (model_class->model_id < 0)
   {
@@ -1309,14 +1312,6 @@ ncm_model_params_get_all (NcmModel *model)
  *
  * Returns: (transfer full): FIXME
  */
-#ifndef NUMCOSMO_HAVE_INLINE
-#define NUMCOSMO_HAVE_INLINE
-#undef _NCM_MODEL_INLINE_H_
-#define G_INLINE_FUNC
-#include "ncm_model.h"
-#undef _NCM_MODEL_INLINE_H_
-#undef NUMCOSMO_HAVE_INLINE
-#endif /* NUMCOSMO_HAVE_INLINE */
 
 /**
  * ncm_model_param_get_scale:
