@@ -25,7 +25,12 @@
 #ifndef _NCM_MODEL_H_
 #define _NCM_MODEL_H_
 
+#include <glib.h>
 #include <glib-object.h>
+#include <gsl/gsl_math.h>
+#include <numcosmo/math/ncm_sparam.h>
+#include <numcosmo/math/ncm_vparam.h>
+#include <numcosmo/math/ncm_reparam.h>
 
 G_BEGIN_DECLS
 
@@ -87,7 +92,7 @@ typedef gdouble (*NcmModelFunc1) (NcmModel *model, const gdouble x);
 
 GType ncm_model_get_type (void) G_GNUC_CONST;
 
-void ncm_model_register_id (NcmModelClass *model_class);
+void ncm_model_class_register_id (NcmModelClass *model_class);
 void ncm_model_class_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec);
 void ncm_model_class_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec);
 void ncm_model_class_add_params (NcmModelClass *model_class, guint sparam_len, guint vparam_len, guint nonparam_prop_len);
@@ -104,10 +109,13 @@ gboolean ncm_model_is_equal (NcmModel *model1, NcmModel *model2);
 
 G_INLINE_FUNC NcmModel *ncm_model_ref (NcmModel *model);
 G_INLINE_FUNC NcmModelID ncm_model_id (NcmModel *model);
+G_INLINE_FUNC NcmModelID ncm_model_id_by_type (GType model_type);
 G_INLINE_FUNC gulong ncm_model_impl (NcmModel *model);
 G_INLINE_FUNC guint ncm_model_len (NcmModel *model);
 G_INLINE_FUNC guint ncm_model_sparam_len (NcmModel *model);
 G_INLINE_FUNC guint ncm_model_vparam_array_len (NcmModel *model);
+G_INLINE_FUNC guint ncm_model_vparam_index (NcmModel *model, guint n, guint i);
+G_INLINE_FUNC guint ncm_model_vparam_len (NcmModel *model, guint n);
 G_INLINE_FUNC const gchar *ncm_model_name (NcmModel *model);
 G_INLINE_FUNC const gchar *ncm_model_nick (NcmModel *model);
 G_INLINE_FUNC NcmReparam *ncm_model_peek_reparam (NcmModel *model);
@@ -168,12 +176,12 @@ ns_name##_set_##name##_impl (NsName##Class *model_class, type f) \
 }
 
 /*
- * Constant model functions call accesseor
+ * Constant model functions call accessor
  */
 #define NCM_MODEL_FUNC0_IMPL(NS_NAME,NsName,ns_name,name) \
 G_INLINE_FUNC gdouble ns_name##_##name (NsName *m) \
 { \
-return NS_NAME##_GET_CLASS (m)->name (NCM_MODEL (m)); \
+  return NS_NAME##_GET_CLASS (m)->name (NCM_MODEL (m)); \
 }
 
 /*
@@ -182,7 +190,7 @@ return NS_NAME##_GET_CLASS (m)->name (NCM_MODEL (m)); \
 #define NCM_MODEL_FUNC1_IMPL(NS_NAME,NsName,ns_name,name) \
 G_INLINE_FUNC gdouble ns_name##_##name (NsName *m, const gdouble x) \
 { \
-return NS_NAME##_GET_CLASS (m)->name (NCM_MODEL (m), x); \
+  return NS_NAME##_GET_CLASS (m)->name (NCM_MODEL (m), x); \
 }
 
 G_END_DECLS
@@ -207,6 +215,20 @@ ncm_model_id (NcmModel *model)
   return NCM_MODEL_GET_CLASS (model)->model_id;
 }
 
+G_INLINE_FUNC NcmModelID
+ncm_model_id_by_type (GType model_type)
+{
+  if (!g_type_is_a (model_type, NCM_TYPE_MODEL))
+    g_error ("ncm_model_id_by_type: type (%s) is not a %s", g_type_name (model_type), g_type_name (NCM_TYPE_MODEL));
+  else
+  {
+    NcmModelClass *model_class = NCM_MODEL_CLASS (g_type_class_ref (model_type));
+    NcmModelID id = model_class->model_id;
+    g_type_class_unref (model_class);
+    return id;
+  }
+}
+
 G_INLINE_FUNC gulong
 ncm_model_impl (NcmModel *model)
 {
@@ -262,8 +284,8 @@ ncm_model_params_finite (NcmModel *model)
   guint i;
   for (i = 0; i < ncm_model_len (model); i++)
   {
-	if (!gsl_finite (ncm_vector_get (model->params, i)))
-	  return FALSE;
+    if (!gsl_finite (ncm_vector_get (model->params, i)))
+      return FALSE;
   }
   return TRUE;
 }
@@ -272,7 +294,7 @@ G_INLINE_FUNC void
 ncm_model_params_update (NcmModel *model)
 {
   if (model->reparam)
-	ncm_reparam_new2old (model->reparam, model, model->reparam->new_params, model->params);
+    ncm_reparam_new2old (model->reparam, model, model->reparam->new_params, model->params);
   model->pkey++;
 }
 
@@ -280,7 +302,7 @@ G_INLINE_FUNC void
 ncm_model_orig_params_update (NcmModel *model)
 {
   if (model->reparam)
-	ncm_reparam_old2new (model->reparam, model, model->params, model->reparam->new_params);
+    ncm_reparam_old2new (model->reparam, model, model->params, model->reparam->new_params);
   model->pkey++;
 }
 
