@@ -33,13 +33,17 @@
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
-#include <numcosmo/numcosmo.h>
+#include "build_cfg.h"
 
-#include <string.h>
-#include <stdio.h>
-#include <glib.h>
-#include <gmp.h>
-#include <mpfr.h>
+#include "math/ncm_mpsf_sbessel_int.h"
+#include "math/mpq_tree.h"
+#include "math/util.h"
+#include "math/ncm_cfg.h"
+#include "math/binsplit.h"
+#include "math/ncm_spline_gsl.h"
+#include "math/ncm_mpsf_trig_int.h"
+
+#include <gsl/gsl_math.h>
 #include <gsl/gsl_poly.h>
 
 /**
@@ -480,8 +484,7 @@ ncm_mpsf_sbessel_jl_xj_integrate_spline_prepare_new (NcmMpsfSBesselIntSpline *in
     ncm_mpsf_sbessel_jl_xj_integral_recur_set_d (xnjlrec, l, x, rnd);
     printf ("%u %u %.15g\n", i, np, x);
   }
-  exit (0);
-
+  g_assert_not_reached ();
 }
 
 /**
@@ -561,7 +564,10 @@ ncm_mpsf_sbessel_jl_xj_integrate_spline_save (NcmMpsfSBesselIntSpline *int_jlspl
   g_assert (int_jlspline->prepared == TRUE);
   FILE *f = ncm_cfg_fopen (filename, "w");
   gchar magic[5] = "NcSBR";
-  fwrite (magic, 1, 5, f);
+
+  if (fwrite (magic, 1, 5, f) != 5)
+    g_error ("ncm_mpsf_sbessel_jl_xj_integrate_spline_save: io error");
+
   NCM_WRITE_UINT32(f, int_jlspline->prec);
   ncm_grid_write (int_jlspline->x, f);
   ncm_grid_write (int_jlspline->k, f);
@@ -596,7 +602,8 @@ ncm_mpsf_sbessel_jl_xj_integrate_spline_load (gchar *filename)
   NcmMpsfSBesselIntSpline *int_jlspline;
   guint32 prec;
 
-  fread (magic, 1, 5, f);
+  if (fread (magic, 1, 5, f) != 5)
+    g_error ("ncm_mpsf_sbessel_jl_xj_integrate_spline_load: io error");
   NCM_READ_UINT32(f, prec);
   x_grid = ncm_grid_read (f);
   k_grid = ncm_grid_read (f);
