@@ -34,7 +34,9 @@
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
-#include <numcosmo/numcosmo.h>
+#include "build_cfg.h"
+
+#include "math/ncm_mset.h"
 
 G_DEFINE_TYPE (NcmMSet, ncm_mset, G_TYPE_OBJECT);
 G_DEFINE_BOXED_TYPE (NcmMSetPIndex, ncm_mset_pindex, ncm_mset_pindex_copy, ncm_mset_pindex_free);
@@ -91,7 +93,7 @@ ncm_mset_pindex_free (NcmMSetPIndex *pi)
 NcmMSet *
 ncm_mset_empty_new (void)
 {
-  return g_object_new (NCM_TYPE_GMSET, NULL);
+  return g_object_new (NCM_TYPE_MSET, NULL);
 }
 
 /**
@@ -623,6 +625,22 @@ ncm_mset_param_get (NcmMSet *mset, NcmModelID gmid, guint pid)
   return ncm_model_param_get (ncm_mset_peek (mset, gmid), pid);
 }
 
+/**
+ * ncm_mset_orig_param_get:
+ * @mset: a #NcmMSet
+ * @gmid: FIXME
+ * @pid: FIXME
+ *
+ * FIXME
+ *
+ * Returns: FIXME
+ */
+gdouble
+ncm_mset_orig_param_get (NcmMSet *mset, NcmModelID gmid, guint pid)
+{
+  return ncm_model_orig_param_get (ncm_mset_peek (mset, gmid), pid);
+}
+
 /**
  * ncm_mset_param_name:
  * @mset: a #NcmMSet
@@ -813,7 +831,7 @@ void
 ncm_mset_fparams_get_vector (NcmMSet *mset, NcmVector *x)
 {
   guint fpi;
-  
+
   for (fpi = 0; fpi < mset->fparam_len; fpi++)
   {
     const NcmMSetPIndex pi = g_array_index (mset->pi_array, NcmMSetPIndex, fpi);
@@ -833,7 +851,7 @@ void
 ncm_mset_fparams_set_vector (NcmMSet *mset, const NcmVector *x)
 {
   guint fpi;
-  
+
   for (fpi = 0; fpi < mset->fparam_len; fpi++)
   {
     const NcmMSetPIndex pi = g_array_index (mset->pi_array, NcmMSetPIndex, fpi);
