@@ -26,16 +26,20 @@
 #ifndef _NCM_MSET_H_
 #define _NCM_MSET_H_
 
+#include <glib.h>
 #include <glib-object.h>
+#include <numcosmo/math/ncm_model.h>
+
+#include <stdio.h>
 
 G_BEGIN_DECLS
 
-#define NCM_TYPE_GMSET             (ncm_mset_get_type ())
-#define NCM_MSET(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), NCM_TYPE_GMSET, NcmMSet))
-#define NCM_MSET_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), NCM_TYPE_GMSET, NcmMSetClass))
-#define NCM_IS_GMSET(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NCM_TYPE_GMSET))
-#define NCM_IS_GMSET_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), NCM_TYPE_GMSET))
-#define NCM_MSET_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), NCM_TYPE_GMSET, NcmMSetClass))
+#define NCM_TYPE_MSET             (ncm_mset_get_type ())
+#define NCM_MSET(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), NCM_TYPE_MSET, NcmMSet))
+#define NCM_MSET_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), NCM_TYPE_MSET, NcmMSetClass))
+#define NCM_IS_MSET(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NCM_TYPE_MSET))
+#define NCM_IS_MSET_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), NCM_TYPE_MSET))
+#define NCM_MSET_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), NCM_TYPE_MSET, NcmMSetClass))
 
 typedef struct _NcmMSetClass NcmMSetClass;
 typedef struct _NcmMSet NcmMSet;
@@ -105,6 +109,7 @@ void ncm_mset_params_print_vals (NcmMSet *mset, FILE *out);
 
 void ncm_mset_param_set (NcmMSet *mset, NcmModelID gmid, guint pid, const gdouble x);
 gdouble ncm_mset_param_get (NcmMSet *mset, NcmModelID gmid, guint pid);
+gdouble ncm_mset_orig_param_get (NcmMSet *mset, NcmModelID gmid, guint pid);
 
 const gchar *ncm_mset_param_name (NcmMSet *mset, NcmModelID gmid, guint pid);
 void ncm_mset_param_set_ftype (NcmMSet *mset, NcmModelID gmid, guint pid, NcmParamType ftype);
