@@ -34,7 +34,9 @@
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
-#include <numcosmo/numcosmo.h>
+#include "build_cfg.h"
+
+#include "math/ncm_mset_func.h"
 
 G_DEFINE_TYPE (NcmMSetFunc, ncm_mset_func, G_TYPE_OBJECT);
 
@@ -53,7 +55,7 @@ G_DEFINE_TYPE (NcmMSetFunc, ncm_mset_func, G_TYPE_OBJECT);
 NcmMSetFunc *
 ncm_mset_func_new (NcmMSetFuncN func, guint np, guint dim, gpointer obj, GDestroyNotify free)
 {
-  NcmMSetFunc *gfunc = g_object_new (NCM_TYPE_GMSET_FUNC, NULL);
+  NcmMSetFunc *gfunc = g_object_new (NCM_TYPE_MSET_FUNC, NULL);
   gfunc->func = func;
   gfunc->np  = np;
   gfunc->dim = dim;
