@@ -34,7 +34,11 @@
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
-#include <numcosmo/numcosmo.h>
+#include "build_cfg.h"
+
+#include "math/ncm_sparam.h"
+#include "nc_hicosmo.h"
+#include "ncm_enum_types.h"
 
 enum
 {
