@@ -33,9 +33,10 @@
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
-#include <numcosmo/numcosmo.h>
+#include "build_cfg.h"
 
-#include <glib.h>
+#include "math/ncm_spline2d_bicubic.h"
+#include "math/ncm_spline_cubic_notaknot.h"
 
 G_DEFINE_TYPE (NcmSpline2dBicubic, ncm_spline2d_bicubic, NCM_TYPE_SPLINE2D);
 
@@ -81,15 +82,6 @@ _ncm_spline2d_bicubic_copy_empty (const NcmSpline2d *s2d)
   return ncm_spline2d_bicubic_new (s2d->s);
 }
 
-#ifndef NUMCOSMO_HAVE_INLINE
-#define NUMCOSMO_HAVE_INLINE
-#undef _NCM_SPLINE_INLINE_H_
-#define G_INLINE_FUNC
-#include "ncm_spline2d_bicubic.h"
-#undef _NCM_SPLINE_INLINE_H_
-#undef NUMCOSMO_HAVE_INLINE
-#endif /* NUMCOSMO_HAVE_INLINE */
-
 static void
 _ncm_spline2d_bicubic_alloc (NcmSpline2dBicubic *s2dbc)
 {
