@@ -25,7 +25,9 @@
 #ifndef _NCM_SPLINE2D_GSL_H_
 #define _NCM_SPLINE2D_GSL_H_
 
+#include <glib.h>
 #include <glib-object.h>
+#include <numcosmo/math/ncm_spline2d.h>
 
 G_BEGIN_DECLS
 
