@@ -25,7 +25,10 @@
 #ifndef _NC_HICOSMO_DE_H_
 #define _NC_HICOSMO_DE_H_
 
+#include <glib.h>
 #include <glib-object.h>
+#include <numcosmo/nc_hicosmo.h>
+#include <numcosmo/likelihood/likelihood.h>
 
 G_BEGIN_DECLS
 
@@ -77,7 +80,7 @@ typedef enum _NcHICosmoDEParams
   NC_HICOSMO_DE_SPARAM_LEN, /*< skip >*/
 } NcHICosmoDEParams;
 
-#define NC_HICOSMO_DE_DEFAULT_H0        NC_C_HUBBLE_CTE_WMAP
+#define NC_HICOSMO_DE_DEFAULT_H0        ncm_c_hubble_cte_wmap ()
 #define NC_HICOSMO_DE_DEFAULT_OMEGA_C   (0.2568)
 #define NC_HICOSMO_DE_DEFAULT_OMEGA_X   (0.70)
 #define NC_HICOSMO_DE_DEFAULT_OMEGA_B   (0.0432)
@@ -101,14 +104,15 @@ struct _NcHICosmoDE
 
 GType nc_hicosmo_de_get_type (void) G_GNUC_CONST;
 
-void nc_hicosmo_de_omega_x2omega_k (NcHICosmo *model);
+void nc_hicosmo_de_set_wmap5_params (NcHICosmo *cosmo);
+void nc_hicosmo_de_omega_x2omega_k (NcHICosmo *cosmo);
 gboolean nc_hicosmo_de_new_add_bbn (NcLikelihood *lh);
 
-void nc_hicosmo_de_set_weff_impl (NcHICosmoDEClass *model_de_class, NcmModelFunc1 f);
-void nc_hicosmo_de_set_dweff_dz_impl (NcHICosmoDEClass *model_de_class, NcmModelFunc1 f);
+void nc_hicosmo_de_set_weff_impl (NcHICosmoDEClass *cosmo_de_class, NcmModelFunc1 f);
+void nc_hicosmo_de_set_dweff_dz_impl (NcHICosmoDEClass *cosmo_de_class, NcmModelFunc1 f);
 
-G_INLINE_FUNC gdouble nc_hicosmo_de_weff (NcHICosmoDE *model, gdouble x);
-G_INLINE_FUNC gdouble nc_hicosmo_de_dweff_dz (NcHICosmoDE *model, gdouble x);
+G_INLINE_FUNC gdouble nc_hicosmo_de_weff (NcHICosmoDE *cosmo, gdouble x);
+G_INLINE_FUNC gdouble nc_hicosmo_de_dweff_dz (NcHICosmoDE *cosmo, gdouble x);
 
 G_END_DECLS
 
