@@ -33,7 +33,9 @@
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
-#include <numcosmo/numcosmo.h>
+#include "build_cfg.h"
+
+#include "model/nc_hicosmo_de_pad.h"
 
 G_DEFINE_TYPE (NcHICosmoDEPad, nc_hicosmo_de_pad, NC_TYPE_HICOSMO_DE);
 
@@ -61,7 +63,11 @@ _nc_hicosmo_de_pad_dweff_dz (NcmModel *model, gdouble z)
 }
 
 /**
+ * nc_hicosmo_de_pad_new:
+ *
  * FIXME
+ *
+ * Returns: FIXME
  */
 NcHICosmoDEPad *
 nc_hicosmo_de_pad_new (void)
