@@ -33,9 +33,10 @@
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
-#include <numcosmo/numcosmo.h>
+#include "build_cfg.h"
 
-#include <glib.h>
+#include "model/nc_hicosmo_de_xcdm.h"
+#include "model/nc_hicosmo_de_linder.h"
 
 G_DEFINE_TYPE (NcHICosmoDEXcdm, nc_hicosmo_de_xcdm, NC_TYPE_HICOSMO_DE);
 
@@ -60,7 +61,11 @@ _nc_hicosmo_de_xcdm_dweff_dz (NcmModel *model, gdouble z)
 }
 
 /**
+ * nc_hicosmo_de_xcdm_new:
+ *
  * FIXME
+ *
+ * Returns: FIXME
  */
 NcHICosmoDEXcdm *
 nc_hicosmo_de_xcdm_new (void)
