@@ -33,9 +33,10 @@
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
-#include <numcosmo/numcosmo.h>
+#include "build_cfg.h"
 
-#include <glib.h>
+#include "model/nc_hicosmo_qspline.h"
+#include "math/ncm_spline_cubic_notaknot.h"
 
 G_DEFINE_TYPE (NcHICosmoQSpline, nc_hicosmo_qspline, NC_TYPE_HICOSMO);
 
@@ -124,7 +125,14 @@ static gdouble _nc_hicosmo_qspline_H0 (NcmModel *model) { return QSPLINE_H0; }
 static gdouble _nc_hicosmo_qspline_Omega_t (NcmModel *model) { return OMEGA_T; }
 
 /**
+ * nc_hicosmo_qspline_new:
+ * @s: FIXME
+ * @np: FIXME
+ * @z_f: FIXME
+ *
  * FIXME
+ *
+ * Returns: FIXME
  */
 NcHICosmoQSpline *
 nc_hicosmo_qspline_new (NcmSpline *s, gsize np, gdouble z_f)
