@@ -33,12 +33,13 @@
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
-#include <numcosmo/numcosmo.h>
+#include "build_cfg.h"
 
-#include <glib.h>
-#include <string.h>
-#include <gsl/gsl_integration.h>
-#include <gsl/gsl_blas.h>
+#include "nc_distance.h"
+#include "nc_macros.h"
+#include "math/integral.h"
+#include "math/ncm_c.h"
+#include "math/ncm_spline_cubic_notaknot.h"
 
 typedef struct _ComovingDistanceArgument{
   NcHICosmo *model;
@@ -212,7 +213,7 @@ nc_distance_modulo2comoving (gint k, gdouble sqrt_Omega_k, gdouble hubble_dist,
 gdouble
 nc_distance_hubble (NcDistance *dist, NcHICosmo *model)
 {
-  return NC_C_c / (nc_hicosmo_H0 (model) * 1.0e3);
+  return ncm_c_c () / (nc_hicosmo_H0 (model) * 1.0e3);
 }
 
 /***************************************************************************
@@ -441,7 +442,7 @@ nc_distance_modulo (NcDistance *dist, NcHICosmo *model, gdouble z)
  ****************************************************************************/
 
 /**
- * nc_distance_angular_diameter_curvature_scale
+ * nc_distance_angular_diameter_curvature_scale:
  * @dist: a #NcDistance
  * @model: a #NcHICosmo
  * @userdata: FIXME
@@ -509,7 +510,7 @@ nc_distance_shift_parameter_lss (NcDistance *dist, NcHICosmo *model)
 }
 
 /**
- * nc_distance_comoving_a0
+ * nc_distance_comoving_a0:
  * @dist: a #NcDistance
  * @model: a #NcHICosmo
  * @z: FIXME
@@ -640,7 +641,7 @@ sound_horizon_integral_argument (gdouble z, gpointer p)
   if (GSL_SIGN(E2) == -1.0)
 	return GSL_POSINF;
   return
-	1.0 / sqrt (E2 * (3.0 + 9.0 / 4.0 * (1.0 + NC_C_NEUTRINO_N_EFF * 0.2271) * omega_b / (omega_r * (1.0 + z))));
+	1.0 / sqrt (E2 * (3.0 + 9.0 / 4.0 * (1.0 + ncm_c_neutrino_n_eff () * 0.2271) * omega_b / (omega_r * (1.0 + z))));
 }
 
 /***************************************************************************
@@ -798,7 +799,6 @@ nc_distance_prepare (NcDistance *dist, NcHICosmo *model)
   return;
 }
 
-
 /**
  * nc_distance_prepare_if_needed:
  * @dist: FIXME,
@@ -806,23 +806,11 @@ nc_distance_prepare (NcDistance *dist, NcHICosmo *model)
  *
  * FIXME
  */
-#ifndef NUMCOSMO_HAVE_INLINE
-#define NUMCOSMO_HAVE_INLINE
-#undef _NC_DISTANCE_INLINE_H_
-#define G_INLINE_FUNC
-#include "nc_distance.h"
-#undef _NC_DISTANCE_INLINE_H_
-#undef NUMCOSMO_HAVE_INLINE
-#endif /* NUMCOSMO_HAVE_INLINE */
-
 static void
 nc_distance_init (NcDistance *dist)
 {
   dist->use_cache = TRUE;
 
-  g_static_mutex_init (&dist->cache_lock);
-  g_static_mutex_init (&dist->update_lock);
-
   dist->comoving_distance_cache = nc_function_cache_new (1, NC_INT_ABS_ERROR, NC_INT_ERROR);
 
   dist->time_cache = nc_function_cache_new (1, NC_INT_ABS_ERROR, NC_INT_ERROR);
@@ -839,8 +827,11 @@ nc_distance_init (NcDistance *dist)
 static void
 nc_distance_constructed (GObject *object)
 {
-  /* Chain up : end */
+  /* Chain up : start */
   G_OBJECT_CLASS (nc_distance_parent_class)->constructed (object);
+	{
+
+	}
 }
 
 static void
@@ -848,9 +839,6 @@ nc_distance_dispose (GObject *object)
 {
   NcDistance *dist = NC_DISTANCE (object);
 
-  g_static_mutex_free (&dist->cache_lock);
-  g_static_mutex_free (&dist->update_lock);
-
   nc_function_cache_free (dist->comoving_distance_cache);
   nc_function_cache_free (dist->time_cache);
   nc_function_cache_free (dist->lookback_time_cache);
