@@ -571,6 +571,8 @@ nc_data_cmb_id_get_type (void)
         { NC_DATA_CMB_SHIFT_PARAMETER_WMAP3, "NC_DATA_CMB_SHIFT_PARAMETER_WMAP3", "shift-parameter-wmap3" },
         { NC_DATA_CMB_SHIFT_PARAMETER_WMAP5, "NC_DATA_CMB_SHIFT_PARAMETER_WMAP5", "shift-parameter-wmap5" },
         { NC_DATA_CMB_DISTANCE_PRIORS_WMAP5, "NC_DATA_CMB_DISTANCE_PRIORS_WMAP5", "distance-priors-wmap5" },
+        { NC_DATA_CMB_SHIFT_PARAMETER_WMAP7, "NC_DATA_CMB_SHIFT_PARAMETER_WMAP7", "shift-parameter-wmap7" },
+        { NC_DATA_CMB_DISTANCE_PRIORS_WMAP7, "NC_DATA_CMB_DISTANCE_PRIORS_WMAP7", "distance-priors-wmap7" },
         { 0, NULL, NULL }
       };
       GType g_define_type_id =
