@@ -34,7 +34,10 @@
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
-#include <numcosmo/numcosmo.h>
+#include "build_cfg.h"
+
+#include "nc_hicosmo.h"
+#include "math/ncm_cfg.h"
 
 G_DEFINE_ABSTRACT_TYPE (NcHICosmo, nc_hicosmo, NCM_TYPE_MODEL);
 
@@ -58,7 +61,7 @@ nc_hicosmo_class_init (NcHICosmoClass *klass)
 {
   GObjectClass* object_class = G_OBJECT_CLASS (klass);
   object_class->finalize = nc_hicosmo_finalize;
-  ncm_model_register_id (NCM_MODEL_CLASS (klass));
+  ncm_model_class_register_id (NCM_MODEL_CLASS (klass));
   NC_HICOSMO_ID = NCM_MODEL_CLASS (klass)->model_id;
 }
 
@@ -69,16 +72,16 @@ _nc_hicosmo_log_all_models_go (GType model_type, guint n)
   GType *models = g_type_children (model_type, &nc);
   for (i = 0; i < nc; i++)
   {
-	guint ncc;
-	GType *modelsc = g_type_children (models[i], &ncc);
+    guint ncc;
+    GType *modelsc = g_type_children (models[i], &ncc);
 
-	g_message ("#  ");
-	for (j = 0; j < n; j++) g_message (" ");
-	g_message ("%s\n", g_type_name (models[i]));
-	if (ncc)
-	  _nc_hicosmo_log_all_models_go (models[i], n + 2);
+    g_message ("#  ");
+    for (j = 0; j < n; j++) g_message (" ");
+    g_message ("%s\n", g_type_name (models[i]));
+    if (ncc)
+      _nc_hicosmo_log_all_models_go (models[i], n + 2);
 
-	g_free (modelsc);
+    g_free (modelsc);
   }
   g_free (models);
 }
@@ -100,20 +103,20 @@ nc_hicosmo_log_all_models (GType parent)
 /**
  * nc_hicosmo_new_from_name:
  * @parent_type: FIXME
- * @model_name: FIXME
+ * @cosmo_name: FIXME
  *
  * FIXME
  *
  * Returns: FIXME
  */
 NcHICosmo *
-nc_hicosmo_new_from_name (GType parent_type, gchar *model_name)
+nc_hicosmo_new_from_name (GType parent_type, gchar *cosmo_name)
 {
-  GObject *obj = ncm_cfg_create_from_string (model_name);
+  GObject *obj = ncm_cfg_create_from_string (cosmo_name);
   GType model_type = G_OBJECT_TYPE (obj);
 
   if (!g_type_is_a (model_type, parent_type))
-	g_error ("nc_hicosmo_new_from_name: NcHICosmo %s do not descend from %s\n", model_name, g_type_name (parent_type));
+	g_error ("nc_hicosmo_new_from_name: NcHICosmo %s do not descend from %s\n", cosmo_name, g_type_name (parent_type));
   return NC_HICOSMO (obj);
 }
 
@@ -247,476 +250,218 @@ NCM_MODEL_SET_IMPL_FUNC(NC_HICOSMO,NcHICosmo,nc_hicosmo,NcmModelFunc1,powspec)
 
 /**
  * nc_hicosmo_H0:
- * @model: FIXME
+ * @cosmo: a #NcHICosmo.
  *
- * FIXME
+ * The value of the Hubble constant in unity of $ms^{-1}kpc^{-1}$.
  *
- * Returns: FIXME
+ * Returns: $H_0$
  */
-/**
- * nc_hicosmo_H0_pf:
- * @model: FIXME
- * @n: FIXME
- *
- * FIXME
- *
- * Returns: FIXME
- */
-/**
- * nc_hicosmo_H0_df:
- * @model: FIXME
- * @pt: FIXME
- * @v: FIXME
- *
- * FIXME
- *
- */
-
 /**
  * nc_hicosmo_Omega_b:
- * @model: FIXME
+ * @cosmo: a #NcHICosmo.
  *
  * FIXME
  *
- * Returns: FIXME
+ * Returns: $\Omega_b$
  */
-/**
- * nc_hicosmo_Omega_b_pf:
- * @model: FIXME
- * @n: FIXME
- *
- * FIXME
- *
- * Returns: FIXME
- */
-/**
- * nc_hicosmo_Omega_b_df:
- * @model: FIXME
- * @pt: FIXME
- * @v: FIXME
- *
- * FIXME
- *
- */
-
 /**
  * nc_hicosmo_Omega_r:
- * @model: FIXME
+ * @cosmo: a #NcHICosmo.
  *
  * FIXME
  *
- * Returns: FIXME
+ * Returns: $\Omega_r$
  */
-/**
- * nc_hicosmo_Omega_r_pf:
- * @model: FIXME
- * @n: FIXME
- *
- * FIXME
- *
- * Returns: FIXME
- */
-/**
- * nc_hicosmo_Omega_r_df:
- * @model: FIXME
- * @pt: FIXME
- * @v: FIXME
- *
- * FIXME
- *
- */
-
 /**
  * nc_hicosmo_Omega_c:
- * @model: FIXME
+ * @cosmo: a #NcHICosmo.
  *
  * FIXME
  *
- * Returns: FIXME
+ * Returns: $\Omega_c$
  */
-/**
- * nc_hicosmo_Omega_c_pf:
- * @model: FIXME
- * @n: FIXME
- *
- * FIXME
- *
- * Returns: FIXME
- */
-/**
- * nc_hicosmo_Omega_c_df:
- * @model: FIXME
- * @pt: FIXME
- * @v: FIXME
- *
- * FIXME
- *
- */
-
 /**
  * nc_hicosmo_Omega_t:
- * @model: FIXME
+ * @cosmo: a #NcHICosmo.
  *
  * FIXME
  *
- * Returns: FIXME
+ * Returns: $\Omega_t$
  */
-/**
- * nc_hicosmo_Omega_t_pf:
- * @model: FIXME
- * @n: FIXME
- *
- * FIXME
- *
- * Returns: FIXME
- */
-/**
- * nc_hicosmo_Omega_t_df:
- * @model: FIXME
- * @pt: FIXME
- * @v: FIXME
- *
- * FIXME
- *
- */
-
 /**
  * nc_hicosmo_T_gamma0:
- * @model: FIXME
+ * @cosmo: a #NcHICosmo.
  *
  * FIXME
  *
- * Returns: FIXME
+ * Returns: $T_{\gamma0}$
  */
-/**
- * nc_hicosmo_T_gamma0_pf:
- * @model: FIXME
- * @n: FIXME
- *
- * FIXME
- *
- * Returns: FIXME
- */
-/**
- * nc_hicosmo_T_gamma0_df:
- * @model: FIXME
- * @pt: FIXME
- * @v: FIXME
- *
- * FIXME
- *
- */
-
 /**
  * nc_hicosmo_sigma_8:
- * @model: FIXME
+ * @cosmo: a #NcHICosmo.
  *
  * FIXME
  *
- * Returns: FIXME
+ * Returns: $\sigma_8$
  */
-/**
- * nc_hicosmo_sigma_8_pf:
- * @model: FIXME
- * @n: FIXME
- *
- * FIXME
- *
- * Returns: FIXME
- */
-/**
- * nc_hicosmo_sigma_8_df:
- * @model: FIXME
- * @pt: FIXME
- * @v: FIXME
- *
- * FIXME
- *
- */
-
 /**
  * nc_hicosmo_z_lss:
- * @model: FIXME
+ * @cosmo: a #NcHICosmo.
  *
  * FIXME
  *
  * Returns: FIXME
  */
-/**
- * nc_hicosmo_z_lss_pf:
- * @model: FIXME
- * @n: FIXME
- *
- * FIXME
- *
- * Returns: FIXME
- */
-/**
- * nc_hicosmo_z_lss_df:
- * @model: FIXME
- * @pt: FIXME
- * @v: FIXME
- *
- * FIXME
- *
- */
-
 /**
  * nc_hicosmo_E2:
- * @model: FIXME
+ * @cosmo: a #NcHICosmo.
  * @x: FIXME
  *
  * FIXME
  *
  * Returns: FIXME
  */
-/**
- * nc_hicosmo_E2_pf:
- * @model: FIXME
- * @x: FIXME
- * @n: FIXME
- *
- * FIXME
- *
- * Returns: FIXME
- */
-/**
- * nc_hicosmo_E2_df:
- * @model: FIXME
- * @pt: FIXME
- * @x: FIXME
- * @v: FIXME
- *
- * FIXME
- *
- */
-
 /**
  * nc_hicosmo_dE2_dz:
- * @model: FIXME
+ * @cosmo: a #NcHICosmo.
  * @x: FIXME
  *
  * FIXME
  *
  * Returns: FIXME
  */
-/**
- * nc_hicosmo_dE2_dz_pf:
- * @model: FIXME
- * @x: FIXME
- * @n: FIXME
- *
- * FIXME
- *
- * Returns: FIXME
- */
-/**
- * nc_hicosmo_dE2_dz_df:
- * @model: FIXME
- * @pt: FIXME
- * @x: FIXME
- * @v: FIXME
- *
- * FIXME
- *
- */
-
 /**
  * nc_hicosmo_d2E2_dz2:
- * @model: FIXME
+ * @cosmo: a #NcHICosmo.
  * @x: FIXME
  *
  * FIXME
  *
  * Returns: FIXME
  */
-/**
- * nc_hicosmo_d2E2_dz2_pf:
- * @model: FIXME
- * @x: FIXME
- * @n: FIXME
- *
- * FIXME
- *
- * Returns: FIXME
- */
-/**
- * nc_hicosmo_d2E2_dz2_df:
- * @model: FIXME
- * @pt: FIXME
- * @x: FIXME
- * @v: FIXME
- *
- * FIXME
- *
- */
-
 /**
  * nc_hicosmo_powspec:
- * @model: FIXME
+ * @cosmo: a #NcHICosmo.
  * @x: FIXME
  *
  * FIXME
  *
  * Returns: FIXME
  */
-/**
- * nc_hicosmo_powspec_pf:
- * @model: FIXME
- * @x: FIXME
- * @n: FIXME
- *
- * FIXME
- *
- * Returns: FIXME
- */
-/**
- * nc_hicosmo_powspec_df:
- * @model: FIXME
- * @pt: FIXME
- * @x: FIXME
- * @v: FIXME
- *
- * FIXME
- *
- */
-
 /**
  * nc_hicosmo_c_H0:
- * @model: FIXME
+ * @cosmo: a #NcHICosmo.
  *
  * FIXME
  *
  * Returns: FIXME
  */
-
 /**
  * nc_hicosmo_Omega_k:
- * @model: a #NcHICosmo.
+ * @cosmo: a #NcHICosmo.
  *
  * FIXME
  *
  * Returns: FIXME
  */
-
 /**
  * nc_hicosmo_Omega_m:
- * @model: a #NcHICosmo.
+ * @cosmo: a #NcHICosmo.
  *
  * The matter density parameter is given by the baryonic plus
  * the cold dark matter density parameters.
  *
  * Returns: The matter density parameter at redshift zero.
  */
-
 /**
  * nc_hicosmo_H:
- * @model: FIXME
+ * @cosmo: a #NcHICosmo.
  * @z: FIXME
  *
- * FIXME
+ * The value of the Hubble function in unity of $ms^{-1}kpc^{-1}$.
  *
- * Returns: FIXME
+ * Returns: $H(z)$
  */
-
 /**
  * nc_hicosmo_h:
- * @model: a #NcHICosmo
+ * @cosmo: a #NcHICosmo
  *
  * FIXME
  *
  * Returns: FIXME
  */
-
 /**
  * nc_hicosmo_grad_h:
- * @model: a #NcHICosmo
+ * @cosmo: a #NcHICosmo
  * @pt: a #NcmFitParams
  * @grad: a #NcmVector
  *
  * FIXME
  */
-
 /**
  * nc_hicosmo_h2:
- * @model: a #NcHICosmo
+ * @cosmo: a #NcHICosmo
  *
  * FIXME
  *
  * Returns: FIXME
  */
-
 /**
  * nc_hicosmo_grad_h2:
- * @model: a #NcHICosmo
+ * @cosmo: a #NcHICosmo
  * @pt: a #NcmFitParams
  * @grad: a #NcmVector
  *
  * FIXME
  */
-
 /**
  * nc_hicosmo_E:
- * @model: a #NcHICosmo
+ * @cosmo: a #NcHICosmo
  * @z: redshift
  *
  * FIXME
  *
  * Returns: FIXME
  */
-
 /**
  * nc_hicosmo_grad_E:
- * @model: a #NcHICosmo
+ * @cosmo: a #NcHICosmo
  * @pt: a #NcmFitParams
  * @z: redshift
  * @grad: a #NcmVector
  *
  * FIXME
  */
-
 /**
  * nc_hicosmo_dH_dz:
- * @model: a #NcHICosmo
+ * @cosmo: a #NcHICosmo
  * @z: redshift
  *
  * FIXME
  *
  * Returns: FIXME
  */
-
-/**
- * nc_hicosmo_Omega_k:
- * @model: a #NcHICosmo.
- *
- * FIXME
- *
- * Returns: FIXME
- */
-
 /**
  * nc_hicosmo_q:
- * @model: a #NcHICosmo
+ * @cosmo: a #NcHICosmo
  * @z: redshift
  *
  * FIXME
  *
  * Returns: FIXME
 */
-
 /**
  * nc_hicosmo_qp:
- * @model: a #NcHICosmo
+ * @cosmo: a #NcHICosmo
  * @z: redshift
  *
  * FIXME
  *
  * Returns: FIXME
  */
-
 /**
  * nc_hicosmo_j:
- * @model: a #NcHICosmo
+ * @cosmo: a #NcHICosmo
  * @z: redshift
  *
  * FIXME
@@ -724,15 +469,6 @@ NCM_MODEL_SET_IMPL_FUNC(NC_HICOSMO,NcHICosmo,nc_hicosmo,NcmModelFunc1,powspec)
  * Returns: FIXME
  */
 
-#ifndef NUMCOSMO_HAVE_INLINE
-#define NUMCOSMO_HAVE_INLINE
-#undef _NC_HICOSMO_INLINE_H_
-#define G_INLINE_FUNC
-#include "nc_hicosmo.h"
-#undef _NC_HICOSMO_INLINE_H_
-#undef NUMCOSMO_HAVE_INLINE
-#endif /* NUMCOSMO_HAVE_INLINE */
-
 static void
 _nc_hicosmo_func0 (NcmMSet *mset, gpointer obj, const gdouble *x, gdouble *f)
 {
@@ -748,25 +484,25 @@ _nc_hicosmo_func1 (NcmMSet *mset, gpointer obj, const gdouble *x, gdouble *f)
 }
 
 /**
- * nc_hicosmo_func0_new:
+ * ncm_mset_func_new_hicosmo_func0:
  * @f0: (scope notified): FIXME
  *
  * Returns: (transfer full): FIXME
  */
 NcmMSetFunc *
-nc_hicosmo_func0_new (NcHICosmoFunc0 f0)
+ncm_mset_func_new_hicosmo_func0 (NcHICosmoFunc0 f0)
 {
   return ncm_mset_func_new (&_nc_hicosmo_func0, 0, 1, f0, NULL);
 }
 
 /**
- * nc_hicosmo_func1_new:
+ * ncm_mset_func_new_hicosmo_func1:
  * @f1: (scope notified): FIXME
  *
  * Returns: (transfer full): FIXME
  */
 NcmMSetFunc *
-nc_hicosmo_func1_new (NcHICosmoFunc1 f1)
+ncm_mset_func_new_hicosmo_func1 (NcHICosmoFunc1 f1)
 {
   return ncm_mset_func_new (&_nc_hicosmo_func1, 1, 1, f1, NULL);
 }
