@@ -25,36 +25,14 @@
 #ifndef _NUMCOSMO_H
 #define _NUMCOSMO_H
 
-#include <string.h>
-#include <math.h>
-#include <complex.h>
-#include <glib.h>
-#include <glib-object.h>
-#include <gsl/gsl_blas.h>
-#include <gsl/gsl_vector.h>
-#include <gsl/gsl_matrix.h>
-#include <gsl/gsl_linalg.h>
-#include <gsl/gsl_rng.h>
-#include <gsl/gsl_randist.h>
-#include <gsl/gsl_integration.h>
-#include <gsl/gsl_bspline.h>
-#include <gsl/gsl_spline.h>
-#include <gsl/gsl_multimin.h>
-#include <gsl/gsl_multifit_nlin.h>
-#include <sundials/sundials_nvector.h>
-
 /* Supported libraries and build configuration */
 #include <numcosmo/build_cfg.h>
 
-#ifdef NUMCOSMO_HAVE_FFTW3
-#include <fftw3.h>
-#endif /* NUMCOSMO_HAVE_FFTW3 */
-
 /* Macros, Constants and Enums */
-#include <numcosmo/ncm_enum_types.h>
 #include <numcosmo/nc_macros.h>
-#include <numcosmo/nc_constants.h>
 #include <numcosmo/nc_enum_types.h>
+#include <numcosmo/ncm_enum_types.h>
+#include <numcosmo/math/ncm_c.h>
 
 /* Base types and components */
 #include <numcosmo/math/ncm_vector.h>
@@ -92,6 +70,9 @@
 #include <numcosmo/nc_hicosmo.h>
 #include <numcosmo/nc_distance.h>
 #include <numcosmo/scalefactor.h>
+/* Cosmic thermodynamics */
+#include <numcosmo/nc_recomb.h>
+#include <numcosmo/nc_recomb_seager.h>
 
 /* Dataset object  */
 #include <numcosmo/data/data.h>
@@ -145,8 +126,6 @@
 #include <numcosmo/model/nc_hicosmo_qspline.h>
 #include <numcosmo/model/quantum_gravity.h>
 
-/* Cosmic thermodynamics */
-#include <numcosmo/thermodyn/recomb.h>
 
 /* Spherical maps, HEALPIX implementation */
 #include <numcosmo/sphere/map.h>
