@@ -34,20 +34,23 @@
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
-#include <numcosmo/numcosmo.h>
+#include "build_cfg.h"
+
+#include "sphere/map.h"
+#include "sphere/healpix.h"
+#include "nc_macros.h"
+#include "math/ncm_c.h"
+#include "math/ncm_cfg.h"
+#include "math/util.h"
 
-#include <glib/gstdio.h>
 #include <string.h>
+#include <gsl/gsl_randist.h>
+#include <gsl/gsl_math.h>
+#include <gsl/gsl_sf_log.h>
+#include <gsl/gsl_sf_legendre.h>
 #ifdef NUMCOSMO_HAVE_CFITSIO
 #include <fitsio.h>
 #endif /* NUMCOSMO_HAVE_CFITSIO */
-#include <gsl/gsl_sf_legendre.h>
-#include <gsl/gsl_complex.h>
-#include <gsl/gsl_complex_math.h>
-#include <gsl/gsl_blas.h>
-#include <gsl/gsl_sf_log.h>
-#include <gsl/gsl_sf_gamma.h>
-#include <gsl/gsl_cblas.h>
 
 /**
  * nc_sphere_map_new: (skip)
@@ -249,9 +252,9 @@ nc_sphere_mapalm_init (NcSphereMapAlm *mapalm, gint lmax)
   for (m = 1; m <= lmax; m++)
   {
     gdouble y_mm;
-    gsl_vector_set (mapalm->lnpoch_m_1_2, m, 0.5 * last_lnpoch - NC_C_LNPI_4);
+    gsl_vector_set (mapalm->lnpoch_m_1_2, m, 0.5 * last_lnpoch - ncm_c_lnpi_4 ());
 
-    y_mm = NC_C_SQRT_1_4PI *
+    y_mm = ncm_c_sqrt_1_4pi () *
       gsl_vector_get (mapalm->sqrt_int, 2*m + 1) / gsl_vector_get(mapalm->sqrt_int, m) * sgn;
     gsl_vector_set (mapalm->sphPmm, m, y_mm);
 
@@ -484,8 +487,8 @@ nc_sphere_mapsht_map2alm_circle (NcSphereMapSHT *mapsht, gint ring, gint ring_si
 
     if(m == 0)
     {
-      y_mm   = NC_C_SQRT_1_4PI;          /* Y00 = 1/sqrt(4pi) */
-      y_mmp1 = x * NC_C_SQRT_3_4PI;
+      y_mm   = ncm_c_sqrt_1_4pi ();          /* Y00 = 1/sqrt(4pi) */
+      y_mmp1 = x * ncm_c_sqrt_3_4pi ();
     }
     else
     {
@@ -631,8 +634,8 @@ nc_sphere_mapsht_alm2map_circle (NcSphereMapSHT *mapsht, gint ring,  gint ring_s
 
     if(m == 0)
     {
-      y_mm   = NC_C_SQRT_1_4PI;          /* Y00 = 1/sqrt(4pi) */
-      y_mmp1 = x * NC_C_SQRT_3_4PI;
+      y_mm   = ncm_c_sqrt_1_4pi ();          /* Y00 = 1/sqrt(4pi) */
+      y_mmp1 = x * ncm_c_sqrt_3_4pi ();
     }
     else
     {
